;*******************************************************************************
/*                    SPRTA TRAVEL DEMAND MODEL
;
;                     PROGRAM:  Voyager 6.4.4
;                     PREFIX :  DO NOT NEED TO BE CODED                       */
;*******************************************************************************
YEAR    = '2040'
YEARNet = '2040'
/* Keyword: ZONES=1723
;           HBW, HBS, HBSch, HBO, W_O, O_O
;           sfdu, mfdu, ardu, ret, mall,
;           off, ind, hti, cc, church,
;           lodge, med, hosp, conv, hotel,
;           pqpl, pqph, school, golf, park,
;           cem, fair, univ, special, s1

;           NUM_OF_SCREENLINES = 8,
;           INDV_NUM_OF_SCREENLINES = 22
*/
; ------------------------------------------------------------------------------
; STEP 2: Check Centroid Connectivity
RUN PGM=MATRIX PRNFILE=".\outputs\step2.prn" MSG='STEP 2: Check Centroid Connectivity'

    ZDATI[1]="outputs\NODE.DBF", Z=N
    ZDATI[2]="outputs\LINK.DBF", Z=A
    ZDATI[3]="outputs\LINK.DBF", Z=B

    ZONES=1723

    IF (ZI.1.X>0 && ZI.2.A==0 && ZI.3.B==0) PRINT,
        LIST=Z(8), FILE="outputs\Unconnected.txt"

ENDRUN
; ------------------------------------------------------------------------------
; STEP 3: Trip Generation
RUN PGM=TRIPGEN PRNFILE=".\outputs\step3.prn" MSG='STEP 3: Trip Generation'

    ; *** FILE I/O ***
    ZDATI = "inputs\LU_@YEAR@SPBO.DBF", Z=TAZ      ; LU, IX, XI, TERM TIME
    PAO   = "outputs\PA_Balanced.DBF", DBF=YES,   ; P/A TRIP ENDS
            LIST=Z(4),P[1],P[2],P[3],P[4],P[5],P[6],P[7],P[8],P[9],P[10],P[11],P[12],P[13],P[14],P[15],P[16],P[17],P[18],
                      A[1],A[2],A[3],A[4],A[5],A[6],A[7],A[8],A[9],A[10],A[11],A[12],A[13],A[14],A[15],A[16],A[17],A[18]

    ; *** PARAMETERS ***
    ZONES=1723                           

    ; *** LOOKUP FUNCTIONS***
    LOOKUP, NAME=TR,                     ; LU TRIP RATES
        LOOKUP[1] =1, RESULT= 4,         ; DAILY TRIP RATE
        INTERPOLATE=FALSE,
        FILE="inputs\TRIPGENRATES_@YEAR@.CSV"

    LOOKUP, NAME=PF,                     ; PRODUCTION FRACTIONS
        LOOKUP[1]=1, RESULT=  5,         ; HBW
        LOOKUP[2]=1, RESULT=  6,         ; HBS
        LOOKUP[3]=1, RESULT=  7,         ; HBSch
        LOOKUP[4]=1, RESULT=  8,         ; HBO
        LOOKUP[5]=1, RESULT=  9,         ; W_O
        LOOKUP[6]=1, RESULT= 10,         ; O_O
        INTERPOLATE=FALSE,
        FILE="inputs\TRIPGENRATES_@YEAR@.CSV"

    LOOKUP, NAME=AF,                     ; ATTRACTION FRACTIONS
        LOOKUP[1]=1, RESULT= 11,         ; HBW
        LOOKUP[2]=1, RESULT= 12,         ; HBS
        LOOKUP[3]=1, RESULT= 13,         ; HBSch
        LOOKUP[4]=1, RESULT= 14,         ; HBO
        LOOKUP[5]=1, RESULT= 15,         ; W_O
        LOOKUP[6]=1, RESULT= 16,         ; O_O
        INTERPOLATE=FALSE,
        FILE="inputs\TRIPGENRATES_@YEAR@.CSV"

    LOOKUP, NAME=IX,                     ; IX FRACTIONS
        LOOKUP[1]=1, RESULT=  5,         ; HBW
        LOOKUP[2]=1, RESULT=  6,         ; HBS
        LOOKUP[3]=1, RESULT=  7,         ; HBSch
        LOOKUP[4]=1, RESULT=  8,         ; HBO
        LOOKUP[5]=1, RESULT=  9,         ; W_O
        LOOKUP[6]=1, RESULT= 10,         ; O_O
        INTERPOLATE=FALSE,
        FILE="inputs\TRIPGENRATES_@YEAR@.CSV"

    LOOKUP, NAME=XI,                     ; XI FRACTIONS
        LOOKUP[1]=1, RESULT= 11,         ; HBW
        LOOKUP[2]=1, RESULT= 12,         ; HBS
        LOOKUP[3]=1, RESULT= 13,         ; HBSch
        LOOKUP[4]=1, RESULT= 14,         ; HBO
        LOOKUP[5]=1, RESULT= 15,         ; W_O
        LOOKUP[6]=1, RESULT= 16,         ; O_O
        INTERPOLATE=FALSE,
        FILE="inputs\TRIPGENRATES_@YEAR@.CSV"

    ; *** PRODUCTION ATTRACTION EQUATIONS ***
    TR_ID = ATYPE*100

    LOOP PURP=1,6
		PURP_IX = PURP + 6      ;index values used for IX trips for each trip purpose. Numbers from 7-12.
		PURP_XI = PURP + 12     ;index values used for XI trips for each trip purpose. Numbers from 13-18.
		
        P[PURP]    = sfdu   * TR(1,TR_ID+ 1) * PF(PURP,TR_ID+ 1) * (1 - IX(PURP,TR_ID)) +
                     mfdu   * TR(1,TR_ID+ 2) * PF(PURP,TR_ID+ 2) * (1 - IX(PURP,TR_ID)) +
                     ardu   * TR(1,TR_ID+ 3) * PF(PURP,TR_ID+ 3) * (1 - IX(PURP,TR_ID)) +
                     ret    * TR(1,TR_ID+ 4) * PF(PURP,TR_ID+ 4) * (1 - IX(PURP,TR_ID)) +
                     mall   * TR(1,TR_ID+ 5) * PF(PURP,TR_ID+ 5) * (1 - IX(PURP,TR_ID)) +
                     off    * TR(1,TR_ID+ 6) * PF(PURP,TR_ID+ 6) * (1 - IX(PURP,TR_ID)) +
                     ind    * TR(1,TR_ID+ 7) * PF(PURP,TR_ID+ 7) * (1 - IX(PURP,TR_ID)) +
                     hti    * TR(1,TR_ID+ 8) * PF(PURP,TR_ID+ 8) * (1 - IX(PURP,TR_ID)) +
                     cc     * TR(1,TR_ID+ 9) * PF(PURP,TR_ID+ 9) * (1 - IX(PURP,TR_ID)) +
                     church * TR(1,TR_ID+10) * PF(PURP,TR_ID+10) * (1 - IX(PURP,TR_ID)) +
                     lodge  * TR(1,TR_ID+11) * PF(PURP,TR_ID+11) * (1 - IX(PURP,TR_ID)) +
                     med    * TR(1,TR_ID+12) * PF(PURP,TR_ID+12) * (1 - IX(PURP,TR_ID)) +
                     hosp   * TR(1,TR_ID+13) * PF(PURP,TR_ID+13) * (1 - IX(PURP,TR_ID)) +
                     conv   * TR(1,TR_ID+14) * PF(PURP,TR_ID+14) * (1 - IX(PURP,TR_ID)) +
                     hotel  * TR(1,TR_ID+15) * PF(PURP,TR_ID+15) * (1 - IX(PURP,TR_ID)) +
                     pqpl   * TR(1,TR_ID+16) * PF(PURP,TR_ID+16) * (1 - IX(PURP,TR_ID)) +
                     pqph   * TR(1,TR_ID+17) * PF(PURP,TR_ID+17) * (1 - IX(PURP,TR_ID)) +
                     school * TR(1,TR_ID+18) * PF(PURP,TR_ID+18) * (1 - IX(PURP,TR_ID)) +
                     golf   * TR(1,TR_ID+19) * PF(PURP,TR_ID+19) * (1 - IX(PURP,TR_ID)) +
                     park   * TR(1,TR_ID+20) * PF(PURP,TR_ID+20) * (1 - IX(PURP,TR_ID)) +
                     cem    * TR(1,TR_ID+21) * PF(PURP,TR_ID+21) * (1 - IX(PURP,TR_ID)) +
                     fair   * TR(1,TR_ID+22) * PF(PURP,TR_ID+22) * (1 - IX(PURP,TR_ID)) +
                     univ   * TR(1,TR_ID+23) * PF(PURP,TR_ID+23) * (1 - IX(PURP,TR_ID)) +
                     special* TR(1,TR_ID+24) * PF(PURP,TR_ID+24) * (1 - IX(PURP,TR_ID)) +
                     s1     * TR(1,TR_ID+25) * PF(PURP,TR_ID+25) * (1 - IX(PURP,TR_ID))

        A[PURP]    = sfdu   * TR(1,TR_ID+ 1) * AF(PURP,TR_ID+ 1) * (1 - XI(PURP,TR_ID)) +
                     mfdu   * TR(1,TR_ID+ 2) * AF(PURP,TR_ID+ 2) * (1 - XI(PURP,TR_ID)) +
                     ardu   * TR(1,TR_ID+ 3) * AF(PURP,TR_ID+ 3) * (1 - XI(PURP,TR_ID)) +
                     ret    * TR(1,TR_ID+ 4) * AF(PURP,TR_ID+ 4) * (1 - XI(PURP,TR_ID)) +
                     mall   * TR(1,TR_ID+ 5) * AF(PURP,TR_ID+ 5) * (1 - XI(PURP,TR_ID)) +
                     off    * TR(1,TR_ID+ 6) * AF(PURP,TR_ID+ 6) * (1 - XI(PURP,TR_ID)) +
                     ind    * TR(1,TR_ID+ 7) * AF(PURP,TR_ID+ 7) * (1 - XI(PURP,TR_ID)) +
                     hti    * TR(1,TR_ID+ 8) * AF(PURP,TR_ID+ 8) * (1 - XI(PURP,TR_ID)) +
                     cc     * TR(1,TR_ID+ 9) * AF(PURP,TR_ID+ 9) * (1 - XI(PURP,TR_ID)) +
                     church * TR(1,TR_ID+10) * AF(PURP,TR_ID+10) * (1 - XI(PURP,TR_ID)) +
                     lodge  * TR(1,TR_ID+11) * AF(PURP,TR_ID+11) * (1 - XI(PURP,TR_ID)) +
                     med    * TR(1,TR_ID+12) * AF(PURP,TR_ID+12) * (1 - XI(PURP,TR_ID)) +
                     hosp   * TR(1,TR_ID+13) * AF(PURP,TR_ID+13) * (1 - XI(PURP,TR_ID)) +
                     conv   * TR(1,TR_ID+14) * AF(PURP,TR_ID+14) * (1 - XI(PURP,TR_ID)) +
                     hotel  * TR(1,TR_ID+15) * AF(PURP,TR_ID+15) * (1 - XI(PURP,TR_ID)) +
                     pqpl   * TR(1,TR_ID+16) * AF(PURP,TR_ID+16) * (1 - XI(PURP,TR_ID)) +
                     pqph   * TR(1,TR_ID+17) * AF(PURP,TR_ID+17) * (1 - XI(PURP,TR_ID)) +
                     school * TR(1,TR_ID+18) * AF(PURP,TR_ID+18) * (1 - XI(PURP,TR_ID)) +
                     golf   * TR(1,TR_ID+19) * AF(PURP,TR_ID+19) * (1 - XI(PURP,TR_ID)) +
                     park   * TR(1,TR_ID+20) * AF(PURP,TR_ID+20) * (1 - XI(PURP,TR_ID)) +
                     cem    * TR(1,TR_ID+21) * AF(PURP,TR_ID+21) * (1 - XI(PURP,TR_ID)) +
                     fair   * TR(1,TR_ID+22) * AF(PURP,TR_ID+22) * (1 - XI(PURP,TR_ID)) +
                     univ   * TR(1,TR_ID+23) * AF(PURP,TR_ID+23) * (1 - XI(PURP,TR_ID)) +
                     special* TR(1,TR_ID+24) * AF(PURP,TR_ID+24) * (1 - XI(PURP,TR_ID)) +
                     s1     * TR(1,TR_ID+25) * AF(PURP,TR_ID+25) * (1 - XI(PURP,TR_ID))

        P[PURP_IX] = sfdu   * TR(1,TR_ID+ 1) * PF(PURP,TR_ID+ 1) * IX(PURP,TR_ID) +
                     mfdu   * TR(1,TR_ID+ 2) * PF(PURP,TR_ID+ 2) * IX(PURP,TR_ID) +
                     ardu   * TR(1,TR_ID+ 3) * PF(PURP,TR_ID+ 3) * IX(PURP,TR_ID) +
                     ret    * TR(1,TR_ID+ 4) * PF(PURP,TR_ID+ 4) * IX(PURP,TR_ID) +
                     mall   * TR(1,TR_ID+ 5) * PF(PURP,TR_ID+ 5) * IX(PURP,TR_ID) +
                     off    * TR(1,TR_ID+ 6) * PF(PURP,TR_ID+ 6) * IX(PURP,TR_ID) +
                     ind    * TR(1,TR_ID+ 7) * PF(PURP,TR_ID+ 7) * IX(PURP,TR_ID) +
                     hti    * TR(1,TR_ID+ 8) * PF(PURP,TR_ID+ 8) * IX(PURP,TR_ID) +
                     cc     * TR(1,TR_ID+ 9) * PF(PURP,TR_ID+ 9) * IX(PURP,TR_ID) +
                     church * TR(1,TR_ID+10) * PF(PURP,TR_ID+10) * IX(PURP,TR_ID) +
                     lodge  * TR(1,TR_ID+11) * PF(PURP,TR_ID+11) * IX(PURP,TR_ID) +
                     med    * TR(1,TR_ID+12) * PF(PURP,TR_ID+12) * IX(PURP,TR_ID) +
                     hosp   * TR(1,TR_ID+13) * PF(PURP,TR_ID+13) * IX(PURP,TR_ID) +
                     conv   * TR(1,TR_ID+14) * PF(PURP,TR_ID+14) * IX(PURP,TR_ID) +
                     hotel  * TR(1,TR_ID+15) * PF(PURP,TR_ID+15) * IX(PURP,TR_ID) +
                     pqpl   * TR(1,TR_ID+16) * PF(PURP,TR_ID+16) * IX(PURP,TR_ID) +
                     pqph   * TR(1,TR_ID+17) * PF(PURP,TR_ID+17) * IX(PURP,TR_ID) +
                     school * TR(1,TR_ID+18) * PF(PURP,TR_ID+18) * IX(PURP,TR_ID) +
                     golf   * TR(1,TR_ID+19) * PF(PURP,TR_ID+19) * IX(PURP,TR_ID) +
                     park   * TR(1,TR_ID+20) * PF(PURP,TR_ID+20) * IX(PURP,TR_ID) +
                     cem    * TR(1,TR_ID+21) * PF(PURP,TR_ID+21) * IX(PURP,TR_ID) +
                     fair   * TR(1,TR_ID+22) * PF(PURP,TR_ID+22) * IX(PURP,TR_ID) +
                     univ   * TR(1,TR_ID+23) * PF(PURP,TR_ID+23) * IX(PURP,TR_ID) +
                     special* TR(1,TR_ID+24) * PF(PURP,TR_ID+24) * IX(PURP,TR_ID) +
                     s1     * TR(1,TR_ID+25) * PF(PURP,TR_ID+25) * IX(PURP,TR_ID)

        A[PURP_IX] = IX_A      ; station weights from land use input file
		
        A[PURP_XI] = sfdu   * TR(1,TR_ID+ 1) * AF(PURP,TR_ID+ 1) * XI(PURP,TR_ID) +
                     mfdu   * TR(1,TR_ID+ 2) * AF(PURP,TR_ID+ 2) * XI(PURP,TR_ID) +
                     ardu   * TR(1,TR_ID+ 3) * AF(PURP,TR_ID+ 3) * XI(PURP,TR_ID) +
                     ret    * TR(1,TR_ID+ 4) * AF(PURP,TR_ID+ 4) * XI(PURP,TR_ID) +
                     mall   * TR(1,TR_ID+ 5) * AF(PURP,TR_ID+ 5) * XI(PURP,TR_ID) +
                     off    * TR(1,TR_ID+ 6) * AF(PURP,TR_ID+ 6) * XI(PURP,TR_ID) +
                     ind    * TR(1,TR_ID+ 7) * AF(PURP,TR_ID+ 7) * XI(PURP,TR_ID) +
                     hti    * TR(1,TR_ID+ 8) * AF(PURP,TR_ID+ 8) * XI(PURP,TR_ID) +
                     cc     * TR(1,TR_ID+ 9) * AF(PURP,TR_ID+ 9) * XI(PURP,TR_ID) +
                     church * TR(1,TR_ID+10) * AF(PURP,TR_ID+10) * XI(PURP,TR_ID) +
                     lodge  * TR(1,TR_ID+11) * AF(PURP,TR_ID+11) * XI(PURP,TR_ID) +
                     med    * TR(1,TR_ID+12) * AF(PURP,TR_ID+12) * XI(PURP,TR_ID) +
                     hosp   * TR(1,TR_ID+13) * AF(PURP,TR_ID+13) * XI(PURP,TR_ID) +
                     conv   * TR(1,TR_ID+14) * AF(PURP,TR_ID+14) * XI(PURP,TR_ID) +
                     hotel  * TR(1,TR_ID+15) * AF(PURP,TR_ID+15) * XI(PURP,TR_ID) +
                     pqpl   * TR(1,TR_ID+16) * AF(PURP,TR_ID+16) * XI(PURP,TR_ID) +
                     pqph   * TR(1,TR_ID+17) * AF(PURP,TR_ID+17) * XI(PURP,TR_ID) +
                     school * TR(1,TR_ID+18) * AF(PURP,TR_ID+18) * XI(PURP,TR_ID) +
                     golf   * TR(1,TR_ID+19) * AF(PURP,TR_ID+19) * XI(PURP,TR_ID) +
                     park   * TR(1,TR_ID+20) * AF(PURP,TR_ID+20) * XI(PURP,TR_ID) +
                     cem    * TR(1,TR_ID+21) * AF(PURP,TR_ID+21) * XI(PURP,TR_ID) +
                     fair   * TR(1,TR_ID+22) * AF(PURP,TR_ID+22) * XI(PURP,TR_ID) +
                     univ   * TR(1,TR_ID+23) * AF(PURP,TR_ID+23) * XI(PURP,TR_ID) +
                     special* TR(1,TR_ID+24) * AF(PURP,TR_ID+24) * XI(PURP,TR_ID) +
                     s1     * TR(1,TR_ID+25) * AF(PURP,TR_ID+25) * XI(PURP,TR_ID)

        P[PURP_XI] = XI_P      ; station weights from land use input file

	  ENDLOOP
    ;---------------------------------------------
    ; Print Summary
    PHASE=ADJUST
        ; *** PRINT TOTAL P/A BEFORE BALANCING ***
        PTOT1  = PTOT(1)
        PTOT2  = PTOT(2)
        PTOT3  = PTOT(3)
        PTOT4  = PTOT(4)
        PTOT5  = PTOT(5)
        PTOT6  = PTOT(6)
        PTOT7  = PTOT(7)
        PTOT8  = PTOT(8)
        PTOT9  = PTOT(9)
        PTOT10 = PTOT(10)
        PTOT11 = PTOT(11)
        PTOT12 = PTOT(12)
        PTOT13 = PTOT(13)
        PTOT14 = PTOT(14)
        PTOT15 = PTOT(15)
        PTOT16 = PTOT(16)
        PTOT17 = PTOT(17)
        PTOT18 = PTOT(18)
        ATOT1  = ATOT(1)
        ATOT2  = ATOT(2)
        ATOT3  = ATOT(3)
        ATOT4  = ATOT(4)
        ATOT5  = ATOT(5)
        ATOT6  = ATOT(6)
        ATOT7  = ATOT(7) 
        ATOT8  = ATOT(8) 
        ATOT9  = ATOT(9) 
        ATOT10 = ATOT(10)
        ATOT11 = ATOT(11)
        ATOT12 = ATOT(12)
        ATOT13 = ATOT(13)
        ATOT14 = ATOT(14)
        ATOT15 = ATOT(15)
        ATOT16 = ATOT(16)
        ATOT17 = ATOT(17)
        ATOT18 = ATOT(18)

        PRINT FORM=13,
            LIST="outputs\BEFORE BALANCING","\n",
                 ",,HBW,HBS,HBSch,HBO,W_O,O_O,HBW_IX,HBS_IX,HBSch_IX,HBO_IX,W_O_IX,O_O_IX,HBW_XI,HBS_XI,HBSch_XI,HBO_XI,W_O_XI,O_O_XI","\n",
                 ",PTOT,",PTOT1,",",PTOT2,",",PTOT3,",",PTOT4,",",PTOT5,",",PTOT6,",",PTOT7,",",PTOT8,",",PTOT9,",",PTOT10,",",PTOT11,",",PTOT12,",",PTOT13,",",PTOT14,",",PTOT15,",",PTOT16,",",PTOT17,",",PTOT18,"\n",
                 ",ATOT,",ATOT1,",",ATOT2,",",ATOT3,",",ATOT4,",",ATOT5,",",ATOT6,",",ATOT7,",",ATOT8,",",ATOT9,",",ATOT10,",",ATOT11,",",ATOT12,",",ATOT13,",",ATOT14,",",ATOT15,",",ATOT16,",",ATOT17,",",ATOT18,"\n",
            FILE="outputs\PA_Summary.CSV", REWIND=T

        ; *** P/A BALANCING ***
        BALANCE A2P=1,2,4,7,8,9,10,11,12,    ; BALANCE TO PRODS FOR OTHERS, IX
                NHB=6,                       ; PRODS SET TO ATTRS FOR NHB
                P2A=3,5,13,14,15,16,17,18    ; BALANCE TO ATTRS FOR SCH, XI

        ; *** PRINT TOTAL P/A AFTER BALANCING ***
        PTOT1  = PTOT(1)
        PTOT2  = PTOT(2)
        PTOT3  = PTOT(3)
        PTOT4  = PTOT(4)
        PTOT5  = PTOT(5)
        PTOT6  = PTOT(6)
        PTOT7  = PTOT(7)
        PTOT8  = PTOT(8)
        PTOT9  = PTOT(9)
        PTOT10 = PTOT(10)
        PTOT11 = PTOT(11)
        PTOT12 = PTOT(12)
        PTOT13 = PTOT(13)
        PTOT14 = PTOT(14)
        PTOT15 = PTOT(15)
        PTOT16 = PTOT(16)
        PTOT17 = PTOT(17)
        PTOT18 = PTOT(18)
        ATOT1  = ATOT(1)
        ATOT2  = ATOT(2)
        ATOT3  = ATOT(3)
        ATOT4  = ATOT(4)
        ATOT5  = ATOT(5)
        ATOT6  = ATOT(6)
        ATOT7  = ATOT(7) 
        ATOT8  = ATOT(8) 
        ATOT9  = ATOT(9) 
        ATOT10 = ATOT(10)
        ATOT11 = ATOT(11)
        ATOT12 = ATOT(12)
        ATOT13 = ATOT(13)
        ATOT14 = ATOT(14)
        ATOT15 = ATOT(15)
        ATOT16 = ATOT(16)
        ATOT17 = ATOT(17)
        ATOT18 = ATOT(18)

        PRINT FORM=13,
            LIST="outputs\AFTER BALANCING","\n",
                 ",,HBW,HBS,HBSch,HBO,W_O,O_O,HBW_IX,HBS_IX,HBSch_IX,HBO_IX,W_O_IX,O_O_IX,HBW_XI,HBS_XI,HBSch_XI,HBO_XI,W_O_XI,O_O_XI","\n",
                 ",PTOT,",PTOT1,",",PTOT2,",",PTOT3,",",PTOT4,",",PTOT5,",",PTOT6,",",PTOT7,",",PTOT8,",",PTOT9,",",PTOT10,",",PTOT11,",",PTOT12,",",PTOT13,",",PTOT14,",",PTOT15,",",PTOT16,",",PTOT17,",",PTOT18,"\n",
                 ",ATOT,",ATOT1,",",ATOT2,",",ATOT3,",",ATOT4,",",ATOT5,",",ATOT6,",",ATOT7,",",ATOT8,",",ATOT9,",",ATOT10,",",ATOT11,",",ATOT12,",",ATOT13,",",ATOT14,",",ATOT15,",",ATOT16,",",ATOT17,",",ATOT18,"\n",
            FILE="outputs\PA_Summary.CSV", APPEND=T
    ENDPHASE

ENDRUN
; ------------------------------------------------------------------------------
; STEP 4a: Balanced PA (PK)
RUN PGM=GENERATION PRNFILE=".\outputs\step4a.prn" MSG='STEP 4a: Balanced PA (PK)'

    ZDATI[1]   = "outputs\PA_Balanced.DBF"                  ; Daily PA
    PAO[1]     = "outputs\PA_Balanced_PK.DBF", DBF=YES,     ; Peak (AM1 + PM1) PA
               LIST=Z(4),P[1],P[2],P[3],P[4],P[5],P[6],P[7],P[8],P[9],P[10],P[11],P[12],P[13],P[14],P[15],P[16],P[17],P[18],
                         A[1],A[2],A[3],A[4],A[5],A[6],A[7],A[8],A[9],A[10],A[11],A[12],A[13],A[14],A[15],A[16],A[17],A[18]
    ZONES=1723
    LOOKUP,                               ; Hourly Factor Lookup
        FILE="inputs\HourlyFactors.csv",
        NAME=PKFAC,
        LOOKUP[1]   =1, RESULT= 2,        ; DEP_HBW
        LOOKUP[101] =1, RESULT= 3,        ; RET_HBW
        LOOKUP[2]   =1, RESULT= 4,        ; DEP_HBS
        LOOKUP[102] =1, RESULT= 5,        ; RET_HBS
        LOOKUP[3]   =1, RESULT= 6,        ; DEP_HBSch
        LOOKUP[103] =1, RESULT= 7,        ; RET_HBSch
        LOOKUP[4]   =1, RESULT= 8,        ; DEP_HBO
        LOOKUP[104] =1, RESULT= 9,        ; RET_HBO
        LOOKUP[5]   =1, RESULT=10,        ; DEP_W_O
        LOOKUP[105] =1, RESULT=11,        ; RET_W_O
        LOOKUP[6]   =1, RESULT=12,        ; DEP_O_O
        LOOKUP[106] =1, RESULT=13,        ; RET_O_O
        LOOKUP[7]   =1, RESULT=14,        ; DEP_IX
        LOOKUP[107] =1, RESULT=15,        ; RET_IX
        LOOKUP[8]   =1, RESULT=16,        ; DEP_XI
        LOOKUP[108] =1, RESULT=17         ; RET_XI

    ;Apply Peak Hour (AM & PM) factors to Daily PA
        P[1] =P1  * ( PKFAC(1,  7) + PKFAC(1,  17) + PKFAC(101,7) + PKFAC(101,17))/100         ; AM and PM Hourly Factors
        P[2] =P2  * ( PKFAC(2,  7) + PKFAC(2,  17) + PKFAC(102,7) + PKFAC(102,17))/100
        P[3] =P3  * ( PKFAC(3,  7) + PKFAC(3,  17) + PKFAC(103,7) + PKFAC(103,17))/100
        P[4] =P4  * ( PKFAC(4,  7) + PKFAC(4,  17) + PKFAC(104,7) + PKFAC(104,17))/100
        P[5] =P5  * ( PKFAC(5,  7) + PKFAC(5,  17) + PKFAC(105,7) + PKFAC(105,17))/100
        P[6] =P6  * ( PKFAC(6,  7) + PKFAC(6,  17) + PKFAC(106,7) + PKFAC(106,17))/100

        ; IX by each trip purpose
        P[7] =P7  * ( PKFAC(7,  7) + PKFAC(7,  17) + PKFAC(107,7) + PKFAC(107,17))/100
        P[8] =P8  * ( PKFAC(7,  7) + PKFAC(7,  17) + PKFAC(107,7) + PKFAC(107,17))/100
        P[9] =P9  * ( PKFAC(7,  7) + PKFAC(7,  17) + PKFAC(107,7) + PKFAC(107,17))/100
        P[10]=P10 * ( PKFAC(7,  7) + PKFAC(7,  17) + PKFAC(107,7) + PKFAC(107,17))/100
        P[11]=P11 * ( PKFAC(7,  7) + PKFAC(7,  17) + PKFAC(107,7) + PKFAC(107,17))/100
        P[12]=P12 * ( PKFAC(7,  7) + PKFAC(7,  17) + PKFAC(107,7) + PKFAC(107,17))/100

        ; XI by each trip purpose
        P[13]=P13 * ( PKFAC(8,  7) + PKFAC(8,  17) + PKFAC(108,7) + PKFAC(108,17))/100
        P[14]=P14 * ( PKFAC(8,  7) + PKFAC(8,  17) + PKFAC(108,7) + PKFAC(108,17))/100
        P[15]=P15 * ( PKFAC(8,  7) + PKFAC(8,  17) + PKFAC(108,7) + PKFAC(108,17))/100
        P[16]=P16 * ( PKFAC(8,  7) + PKFAC(8,  17) + PKFAC(108,7) + PKFAC(108,17))/100
        P[17]=P17 * ( PKFAC(8,  7) + PKFAC(8,  17) + PKFAC(108,7) + PKFAC(108,17))/100
        P[18]=P18 * ( PKFAC(8,  7) + PKFAC(8,  17) + PKFAC(108,7) + PKFAC(108,17))/100

        A[1] =A1  * ( PKFAC(1,  7) + PKFAC(1,  17) + PKFAC(101,7) + PKFAC(101,17))/100
        A[2] =A2  * ( PKFAC(2,  7) + PKFAC(2,  17) + PKFAC(102,7) + PKFAC(102,17))/100
        A[3] =A3  * ( PKFAC(3,  7) + PKFAC(3,  17) + PKFAC(103,7) + PKFAC(103,17))/100
        A[4] =A4  * ( PKFAC(4,  7) + PKFAC(4,  17) + PKFAC(104,7) + PKFAC(104,17))/100
        A[5] =A5  * ( PKFAC(5,  7) + PKFAC(5,  17) + PKFAC(105,7) + PKFAC(105,17))/100
        A[6] =A6  * ( PKFAC(6,  7) + PKFAC(6,  17) + PKFAC(106,7) + PKFAC(106,17))/100

        ; IX by each trip purpose
        A[7] =A7  * ( PKFAC(7,  7) + PKFAC(7,  17) + PKFAC(107,7) + PKFAC(107,17))/100
        A[8] =A8  * ( PKFAC(7,  7) + PKFAC(7,  17) + PKFAC(107,7) + PKFAC(107,17))/100
        A[9] =A9  * ( PKFAC(7,  7) + PKFAC(7,  17) + PKFAC(107,7) + PKFAC(107,17))/100
        A[10]=A10 * ( PKFAC(7,  7) + PKFAC(7,  17) + PKFAC(107,7) + PKFAC(107,17))/100
        A[11]=A11 * ( PKFAC(7,  7) + PKFAC(7,  17) + PKFAC(107,7) + PKFAC(107,17))/100
        A[12]=A12 * ( PKFAC(7,  7) + PKFAC(7,  17) + PKFAC(107,7) + PKFAC(107,17))/100

        ; XI by each trip purpose
        A[13]=A13 * ( PKFAC(8,  7) + PKFAC(8,  17) + PKFAC(108,7) + PKFAC(108,17))/100
        A[14]=A14 * ( PKFAC(8,  7) + PKFAC(8,  17) + PKFAC(108,7) + PKFAC(108,17))/100
        A[15]=A15 * ( PKFAC(8,  7) + PKFAC(8,  17) + PKFAC(108,7) + PKFAC(108,17))/100
        A[16]=A16 * ( PKFAC(8,  7) + PKFAC(8,  17) + PKFAC(108,7) + PKFAC(108,17))/100
        A[17]=A17 * ( PKFAC(8,  7) + PKFAC(8,  17) + PKFAC(108,7) + PKFAC(108,17))/100
        A[18]=A18 * ( PKFAC(8,  7) + PKFAC(8,  17) + PKFAC(108,7) + PKFAC(108,17))/100

    ;---------------------------------------------
    ; Print Summary
    PHASE=ADJUST
        ; *** PRINT TOTAL P/A BEFORE BALANCING ***
        PTOT1  = PTOT(1)
        PTOT2  = PTOT(2)
        PTOT3  = PTOT(3)
        PTOT4  = PTOT(4)
        PTOT5  = PTOT(5)
        PTOT6  = PTOT(6)
        PTOT7  = PTOT(7)
        PTOT8  = PTOT(8)
        PTOT9  = PTOT(9)
        PTOT10 = PTOT(10)
        PTOT11 = PTOT(11)
        PTOT12 = PTOT(12)
        PTOT13 = PTOT(13)
        PTOT14 = PTOT(14)
        PTOT15 = PTOT(15)
        PTOT16 = PTOT(16)
        PTOT17 = PTOT(17)
        PTOT18 = PTOT(18)
        ATOT1  = ATOT(1)
        ATOT2  = ATOT(2)
        ATOT3  = ATOT(3)
        ATOT4  = ATOT(4)
        ATOT5  = ATOT(5)
        ATOT6  = ATOT(6)
        ATOT7  = ATOT(7) 
        ATOT8  = ATOT(8) 
        ATOT9  = ATOT(9) 
        ATOT10 = ATOT(10)
        ATOT11 = ATOT(11)
        ATOT12 = ATOT(12)
        ATOT13 = ATOT(13)
        ATOT14 = ATOT(14)
        ATOT15 = ATOT(15)
        ATOT16 = ATOT(16)
        ATOT17 = ATOT(17)
        ATOT18 = ATOT(18)

        PRINT FORM=13,
            LIST="outputs\BEFORE BALANCING","\n",
                 ",,HBW,HBS,HBSch,HBO,W_O,O_O,HBW_IX,HBS_IX,HBSch_IX,HBO_IX,W_O_IX,O_O_IX,HBW_XI,HBS_XI,HBSch_XI,HBO_XI,W_O_XI,O_O_XI","\n",
                 ",PTOT,",PTOT1,",",PTOT2,",",PTOT3,",",PTOT4,",",PTOT5,",",PTOT6,",",PTOT7,",",PTOT8,",",PTOT9,",",PTOT10,",",PTOT11,",",PTOT12,",",PTOT13,",",PTOT14,",",PTOT15,",",PTOT16,",",PTOT17,",",PTOT18,"\n",
                 ",ATOT,",ATOT1,",",ATOT2,",",ATOT3,",",ATOT4,",",ATOT5,",",ATOT6,",",ATOT7,",",ATOT8,",",ATOT9,",",ATOT10,",",ATOT11,",",ATOT12,",",ATOT13,",",ATOT14,",",ATOT15,",",ATOT16,",",ATOT17,",",ATOT18,"\n",
            FILE="outputs\PA_Summary_PK.CSV", REWIND=T

        ; *** P/A BALANCING ***
        BALANCE A2P=1,2,4,7,8,9,10,11,12,    ; BALANCE TO PRODS FOR OTHERS, IX
                NHB=6,                       ; PRODS SET TO ATTRS FOR NHB
                P2A=3,5,13,14,15,16,17,18    ; BALANCE TO ATTRS FOR SCH, XI

        ; *** PRINT TOTAL P/A AFTER BALANCING ***
        PTOT1  = PTOT(1)
        PTOT2  = PTOT(2)
        PTOT3  = PTOT(3)
        PTOT4  = PTOT(4)
        PTOT5  = PTOT(5)
        PTOT6  = PTOT(6)
        PTOT7  = PTOT(7)
        PTOT8  = PTOT(8)
        PTOT9  = PTOT(9)
        PTOT10 = PTOT(10)
        PTOT11 = PTOT(11)
        PTOT12 = PTOT(12)
        PTOT13 = PTOT(13)
        PTOT14 = PTOT(14)
        PTOT15 = PTOT(15)
        PTOT16 = PTOT(16)
        PTOT17 = PTOT(17)
        PTOT18 = PTOT(18)
        ATOT1  = ATOT(1)
        ATOT2  = ATOT(2)
        ATOT3  = ATOT(3)
        ATOT4  = ATOT(4)
        ATOT5  = ATOT(5)
        ATOT6  = ATOT(6)
        ATOT7  = ATOT(7) 
        ATOT8  = ATOT(8) 
        ATOT9  = ATOT(9) 
        ATOT10 = ATOT(10)
        ATOT11 = ATOT(11)
        ATOT12 = ATOT(12)
        ATOT13 = ATOT(13)
        ATOT14 = ATOT(14)
        ATOT15 = ATOT(15)
        ATOT16 = ATOT(16)
        ATOT17 = ATOT(17)
        ATOT18 = ATOT(18)

        PRINT FORM=13,
            LIST="outputs\AFTER BALANCING","\n",
                 ",,HBW,HBS,HBSch,HBO,W_O,O_O,HBW_IX,HBS_IX,HBSch_IX,HBO_IX,W_O_IX,O_O_IX,HBW_XI,HBS_XI,HBSch_XI,HBO_XI,W_O_XI,O_O_XI","\n",
                 ",PTOT,",PTOT1,",",PTOT2,",",PTOT3,",",PTOT4,",",PTOT5,",",PTOT6,",",PTOT7,",",PTOT8,",",PTOT9,",",PTOT10,",",PTOT11,",",PTOT12,",",PTOT13,",",PTOT14,",",PTOT15,",",PTOT16,",",PTOT17,",",PTOT18,"\n",
                 ",ATOT,",ATOT1,",",ATOT2,",",ATOT3,",",ATOT4,",",ATOT5,",",ATOT6,",",ATOT7,",",ATOT8,",",ATOT9,",",ATOT10,",",ATOT11,",",ATOT12,",",ATOT13,",",ATOT14,",",ATOT15,",",ATOT16,",",ATOT17,",",ATOT18,"\n",
            FILE="outputs\PA_Summary_PK.CSV", APPEND=T
    ENDPHASE
ENDRUN
; ------------------------------------------------------------------------------
; STEP 4b: Balanced PA (OP)
RUN PGM=GENERATION PRNFILE=".\outputs\step4b.prn" MSG='STEP 4b: Balanced PA (OP)'

    ZDATI[1]   = "outputs\PA_Balanced.DBF"                  ; Daily PA
    ZDATI[2]   = "outputs\PA_Balanced_Pk.DBF"               ; Peak (AM1 + PM1) PA
    PAO[1]     = "outputs\PA_Balanced_OP.DBF", DBF=YES,     ; Off Peak Period PA
            LIST=Z(4),P[1],P[2],P[3],P[4],P[5],P[6],P[7],P[8],P[9],P[10],P[11],P[12],P[13],P[14],P[15],P[16],P[17],P[18],
                      A[1],A[2],A[3],A[4],A[5],A[6],A[7],A[8],A[9],A[10],A[11],A[12],A[13],A[14],A[15],A[16],A[17],A[18]
    ZONES=1723
    ;OP = Daily - PK
        P[1] =ZI.1.P1  - ZI.2.P1
        P[2] =ZI.1.P2  - ZI.2.P2
        P[3] =ZI.1.P3  - ZI.2.P3
        P[4] =ZI.1.P4  - ZI.2.P4
        P[5] =ZI.1.P5  - ZI.2.P5
        P[6] =ZI.1.P6  - ZI.2.P6
        P[7] =ZI.1.P7  - ZI.2.P7
        P[8] =ZI.1.P8  - ZI.2.P8
        P[9] =ZI.1.P9  - ZI.2.P9
        P[10]=ZI.1.P10 - ZI.2.P10
        P[11]=ZI.1.P11 - ZI.2.P11
        P[12]=ZI.1.P12 - ZI.2.P12
        P[13]=ZI.1.P13 - ZI.2.P13
        P[14]=ZI.1.P14 - ZI.2.P14
        P[15]=ZI.1.P15 - ZI.2.P15
        P[16]=ZI.1.P16 - ZI.2.P16
        P[17]=ZI.1.P17 - ZI.2.P17
        P[18]=ZI.1.P18 - ZI.2.P18
        A[1] =ZI.1.A1  - ZI.2.A1
        A[2] =ZI.1.A2  - ZI.2.A2
        A[3] =ZI.1.A3  - ZI.2.A3
        A[4] =ZI.1.A4  - ZI.2.A4
        A[5] =ZI.1.A5  - ZI.2.A5
        A[6] =ZI.1.A6  - ZI.2.A6
        A[7] =ZI.1.A7  - ZI.2.A7
        A[8] =ZI.1.A8  - ZI.2.A8
        A[9] =ZI.1.A9  - ZI.2.A9
        A[10]=ZI.1.A10 - ZI.2.A10
        A[11]=ZI.1.A11 - ZI.2.A11
        A[12]=ZI.1.A12 - ZI.2.A12
        A[13]=ZI.1.A13 - ZI.2.A13
        A[14]=ZI.1.A14 - ZI.2.A14
        A[15]=ZI.1.A15 - ZI.2.A15
        A[16]=ZI.1.A16 - ZI.2.A16
        A[17]=ZI.1.A17 - ZI.2.A17
        A[18]=ZI.1.A18 - ZI.2.A18
ENDRUN
; ------------------------------------------------------------------------------
; Model feedback loop start
LOOP iteration=1,3
    ; STEP 5: Skimming
    IF (iteration=1)
        ; ------------------------------------------------------------------------------
        ; STEP 5a: Skimming - iteration=1
        LOOP p=1,2          ; Period Loop Start
            IF (p=1) PER = 'PK'
            IF (p=2) PER = 'OP'
            RUN PGM=HWYLOAD PRNFILE=".\outputs\step5a_@PER@.prn" MSG='STEP 5a: Skimming - iteration=1'
                NETI     = "outputs\Roads_@YEARNet@.net"
                TURNPENI = "inputs\TURNPEN_@YEARNet@.CSV"           ; Turn Penalty
                MATO     = "outputs\TEMP_SKIM_@YEAR@_@PER@.MAT",    ; Temp Skim Matrix for Period
                           MO=1, NAME=TIME

                ; PARAMETERS
                ZONES=1723                                 

                PHASE=LINKREAD
                    T0 = li.distance * 60 / CmpNumRetNum(li.speed,'=',0,1,li.speed)
                    ; Link Group - for pathload
                    IF (LI.HOVLINK=0) ADDTOGROUP=1        ; no restriction
                    IF (LI.HOVLINK=1) ADDTOGROUP=2        ; walk
                    IF (LI.HOVLINK=2) ADDTOGROUP=3        ; HOV lanes
                    IF (LI.HOVLINK=3) ADDTOGROUP=4        ; HOV bypassses
                    IF (li.SPEED  <3) ADDTOGROUP=2        ; disabled links
                ENDPHASE

                PHASE=ILOOP
                        PATHLOAD PATH=TIME, EXCLUDEGRP=2, PENI=1, MW[1]=PATHTRACE(TIME),          ; Skim Free-Flow Travel Time with all links
                                       NOACCESS=0                                                 ; No Access Cell Value = 0
                ENDPHASE
            ENDRUN
        ENDLOOP             ; Period Loop End
    ELSEIF (iteration>1)
        ; ------------------------------------------------------------------------------
        ; STEP 5b: Skimming - iteration>1
        LOOP p=1,2          ; Period Loop Start
            IF (p=1)
                PER    = 'PK'
                PER_HR = 'AM1'
            ELSEIF (p=2)
                PER    = 'OP'
                PER_HR = 'OP'
            ENDIF
            RUN PGM=HWYLOAD PRNFILE=".\outputs\step5b_@PER@.prn" MSG='STEP 5b: Skimming - iteration>1'
                NETI     = "outputs\LOADED_@YEAR@_@PER_HR@.net"
                TURNPENI = "inputs\TURNPEN_@YEARNet@.CSV"           ; Turn Penalty
                MATO     = "outputs\TEMP_SKIM_@YEAR@_@PER@.MAT",    ; Temp Skim Matrix for Period
                           MO=1, NAME=TIME

                ; PARAMETERS
                ZONES=1723                                 

                PHASE=LINKREAD
                    T0 = LI.TIME_1
                    ; Link Group - for pathload
                    IF (LI.HOVLINK=0) ADDTOGROUP=1        ; no restriction
                    IF (LI.HOVLINK=1) ADDTOGROUP=2        ; walk
                    IF (LI.HOVLINK=2) ADDTOGROUP=3        ; HOV lanes
                    IF (LI.HOVLINK=3) ADDTOGROUP=4        ; HOV bypassses
                    IF (li.SPEED  <3) ADDTOGROUP=2        ; disabled links
                ENDPHASE

                PHASE=ILOOP
                        PATHLOAD PATH=TIME, EXCLUDEGRP=2, PENI=1, MW[1]=PATHTRACE(TIME),          ; Skim Free-Flow Travel Time with all links
                                       NOACCESS=0                                                 ; No Access Cell Value = 0
                ENDPHASE
            ENDRUN
        ENDLOOP             ; Period Loop End
    ENDIF
    ; ------------------------------------------------------------------------------
    ;STEP 6: Skimming: Set Intrazonal and Add Terminal Times
    LOOP p=1,2          ; Period Loop Start
        IF (p=1) PER = 'PK'
        IF (p=2) PER = 'OP'
        RUN PGM=MATRIX PRNFILE=".\outputs\step6_@PER@.prn" MSG='STEP 6: Skimming: Set Intrazonal and Add Terminal Times'
            MATI  = "outputs\TEMP_SKIM_@YEAR@_@PER@.MAT"    ; Temp Skim Matrix
            ZDATI = "inputs\LU_@YEAR@SPBO.DBF"              ; Terminal Time
            MATO  = "outputs\SKIM_@YEAR@_@PER@.MAT",        ; Skim Matrix
                    MO=1, NAME=TIME

            MW[1] = MI.1.TIME
        ;    IF (ROWSUM(1)=0)                                            ; QUIT IF FOUND NOACCESS ZONES
        ;        ABORT MSG='*** FOUND INACCESSIBLE ZONE ***'
        ;    ENDIF

            MW[1][I]=LOWEST(1,2,0.001,999,I)                            ; TIME TO NEAREST 2 ZONES
            IF (LOWCNT>0)
                MW[1][I]=(MW[1][I]/LOWCNT)/2                            ; SET INTRAS TO 50% OF TIME TO NEAREST 2 ZONES
            ELSE
                MW[1][I]=0                                              ; SET INTRAS TO 0
            ENDIF

            MW[1] = MW[1] + ZI.1.TERMINAL_O[I]                          ; ADD ORIGIN ZONE TERMINAL TIME

            JLOOP
                MW[1][J] = MW[1][J] + ZI.1.TERMINAL_D[J]                ; ADD DEST ZONE TERMINAL TIME
            ENDJLOOP

        ENDRUN
    ENDLOOP             ; Period Loop End
    ; ------------------------------------------------------------------------------
    ; STEP 7: Trip Distribution
    LOOP p=1,2          ; Period Loop Start
        IF (p=1) PER = 'PK'
        IF (p=2) PER = 'OP'
        RUN PGM=TRIPDIST PRNFILE=".\outputs\step7_@PER@.prn" MSG='STEP 7: Trip Distribution'
            MATI[1]  = "outputs\SKIM_@YEAR@_@PER@.MAT"        ; Skim Matrix
            ZDATI[2] = "outputs\PA_Balanced_@PER@.DBF",Z=Z    ; P/A Trip-ends
            MATO     = "outputs\TEMP_PA_@YEAR@_@PER@.MAT",    ;
                       MO=1-18,
                       NAME=HBW,HBS,HBSch,HBO,W_O,O_O,HBW_IX,HBS_IX,HBSch_IX,HBO_IX,W_O_IX,O_O_IX,HBW_XI,HBS_XI,HBSch_XI,HBO_XI,W_O_XI,O_O_XI
            ; *** PARAMETERS ***
            MAXITERS = 25
            MAXRMSE  = 10
            ; *** LOOKUP FUNCTION***
            LOOKUP,                                             ; FRICTION FACTOR FILE
                FILE="inputs\FRICTIONFACTORS.CSV",
                NAME=FF,
                LOOKUP[1]  =1, RESULT=2,
                LOOKUP[2]  =1, RESULT=3,
                LOOKUP[3]  =1, RESULT=4,
                LOOKUP[4]  =1, RESULT=5,
                LOOKUP[5]  =1, RESULT=6,
                LOOKUP[6]  =1, RESULT=7,
                LOOKUP[7]  =1, RESULT=8,
                LOOKUP[8]  =1, RESULT=9,
                LOOKUP[9]  =1, RESULT=10,
                LOOKUP[10] =1, RESULT=11,
                LOOKUP[11] =1, RESULT=12,
                LOOKUP[12] =1, RESULT=13,
                LOOKUP[13] =1, RESULT=14,
                LOOKUP[14] =1, RESULT=15,
                LOOKUP[15] =1, RESULT=16,
                LOOKUP[16] =1, RESULT=17,
                LOOKUP[17] =1, RESULT=18,
                LOOKUP[18] =1, RESULT=19,
                INTERPOLATE=Y,
                FAIL=0,0

            ;  SETUP THE WORKING P AND A
            SETPA P[1] =P1     A[1] =A1
            SETPA P[2] =P2     A[2] =A2
            SETPA P[3] =P3     A[3] =A3
            SETPA P[4] =P4     A[4] =A4
            SETPA P[5] =P5     A[5] =A5
            SETPA P[6] =P6     A[6] =A6
            SETPA P[7] =P7     A[7] =A7
            SETPA P[8] =P8     A[8] =A8
            SETPA P[9] =P9     A[9] =A9
            SETPA P[10]=P10    A[10]=A10
            SETPA P[11]=P11    A[11]=A11
            SETPA P[12]=P12    A[12]=A12
            SETPA P[13]=P13    A[13]=A13
            SETPA P[14]=P14    A[14]=A14
            SETPA P[15]=P15    A[15]=A15
            SETPA P[16]=P16    A[16]=A16
            SETPA P[17]=P17    A[17]=A17
            SETPA P[18]=P18    A[18]=A18

            MW[19]=MI.1.TIME

            ; APPLY GRAVITY MODEL FOR ALL EXCEPT SCHOOL TRIPS
            GRAVITY   PURPOSE=1,  LOS=MW[19], FFACTORS=FF
            GRAVITY   PURPOSE=2,  LOS=MW[19], FFACTORS=FF
            GRAVITY   PURPOSE=3,  LOS=MW[19], FFACTORS=FF
            GRAVITY   PURPOSE=4,  LOS=MW[19], FFACTORS=FF
            GRAVITY   PURPOSE=5,  LOS=MW[19], FFACTORS=FF
            GRAVITY   PURPOSE=6,  LOS=MW[19], FFACTORS=FF
            GRAVITY   PURPOSE=7,  LOS=MW[19], FFACTORS=FF
            GRAVITY   PURPOSE=8,  LOS=MW[19], FFACTORS=FF
            GRAVITY   PURPOSE=9,  LOS=MW[19], FFACTORS=FF
            GRAVITY   PURPOSE=10, LOS=MW[19], FFACTORS=FF
            GRAVITY   PURPOSE=11, LOS=MW[19], FFACTORS=FF
            GRAVITY   PURPOSE=12, LOS=MW[19], FFACTORS=FF
            GRAVITY   PURPOSE=13, LOS=MW[19], FFACTORS=FF
            GRAVITY   PURPOSE=14, LOS=MW[19], FFACTORS=FF
            GRAVITY   PURPOSE=15, LOS=MW[19], FFACTORS=FF
            GRAVITY   PURPOSE=16, LOS=MW[19], FFACTORS=FF
            GRAVITY   PURPOSE=17, LOS=MW[19], FFACTORS=FF
            GRAVITY   PURPOSE=18, LOS=MW[19], FFACTORS=FF

            ; TRIP LENGTH FREQUENCY REPORT
            FREQUENCY VALUEMW=1,  BASEMW=19, RANGE=1-80         ; FREQUENCY DISTRIBUTION
            FREQUENCY VALUEMW=2,  BASEMW=19, RANGE=1-80         ; FREQUENCY DISTRIBUTION
            FREQUENCY VALUEMW=3,  BASEMW=19, RANGE=1-80         ; FREQUENCY DISTRIBUTION
            FREQUENCY VALUEMW=4,  BASEMW=19, RANGE=1-80         ; FREQUENCY DISTRIBUTION
            FREQUENCY VALUEMW=5,  BASEMW=19, RANGE=1-80         ; FREQUENCY DISTRIBUTION
            FREQUENCY VALUEMW=6,  BASEMW=19, RANGE=1-80         ; FREQUENCY DISTRIBUTION
            FREQUENCY VALUEMW=7,  BASEMW=19, RANGE=1-80         ; FREQUENCY DISTRIBUTION
            FREQUENCY VALUEMW=8,  BASEMW=19, RANGE=1-80         ; FREQUENCY DISTRIBUTION
            FREQUENCY VALUEMW=9,  BASEMW=19, RANGE=1-80         ; FREQUENCY DISTRIBUTION
            FREQUENCY VALUEMW=10, BASEMW=19, RANGE=1-80         ; FREQUENCY DISTRIBUTION
            FREQUENCY VALUEMW=11, BASEMW=19, RANGE=1-80         ; FREQUENCY DISTRIBUTION
            FREQUENCY VALUEMW=12, BASEMW=19, RANGE=1-80         ; FREQUENCY DISTRIBUTION
            FREQUENCY VALUEMW=13, BASEMW=19, RANGE=1-80         ; FREQUENCY DISTRIBUTION
            FREQUENCY VALUEMW=14, BASEMW=19, RANGE=1-80         ; FREQUENCY DISTRIBUTION
            FREQUENCY VALUEMW=15, BASEMW=19, RANGE=1-80         ; FREQUENCY DISTRIBUTION
            FREQUENCY VALUEMW=16, BASEMW=19, RANGE=1-80         ; FREQUENCY DISTRIBUTION
            FREQUENCY VALUEMW=17, BASEMW=19, RANGE=1-80         ; FREQUENCY DISTRIBUTION
            FREQUENCY VALUEMW=18, BASEMW=19, RANGE=1-80         ; FREQUENCY DISTRIBUTION

        ENDRUN
    ENDLOOP             ; Period Loop End
    ; ------------------------------------------------------------------------------
    ; STEP 8a: Split Peak Period Matrix into Peak Hour OD Matrices
    LOOP hr=1,2          ; Peak Hour Loop Start
        PH_AM  = 7
        PH_PM  = 17
        IF (hr=1)
            PEAKHOUR = 7        ;PkHr
            PH_NAME  = 'AM1'
        ELSE
            PEAKHOUR = 17
            PH_NAME  = 'PM1'
        ENDIF
        RUN PGM=MATRIX PRNFILE=".\outputs\step8a_@PH_NAME@.prn" MSG='STEP 8a: Split Peak Period Matrix into Peak Hour PA Matrices'
            MATI[1] = "outputs\TEMP_PA_@YEAR@_PK.MAT"
            MATO    = "outputs\TEMP_OD_@YEAR@_@PH_NAME@.MAT",
                       MO=1-18,
                       NAME=HBW,HBS,HBSch,HBO,W_O,O_O,HBW_IX,HBS_IX,HBSch_IX,HBO_IX,W_O_IX,O_O_IX,HBW_XI,HBS_XI,HBSch_XI,HBO_XI,W_O_XI,O_O_XI

            LOOKUP,                               ; Hourly Factor Lookup
                FILE="inputs\HourlyFactors.csv",
                NAME=PKFAC,
                LOOKUP[1]   =1, RESULT= 2,        ; DEP_HBW
                LOOKUP[101] =1, RESULT= 3,        ; RET_HBW
                LOOKUP[2]   =1, RESULT= 4,        ; DEP_HBS
                LOOKUP[102] =1, RESULT= 5,        ; RET_HBS
                LOOKUP[3]   =1, RESULT= 6,        ; DEP_HBSch
                LOOKUP[103] =1, RESULT= 7,        ; RET_HBSch
                LOOKUP[4]   =1, RESULT= 8,        ; DEP_HBO
                LOOKUP[104] =1, RESULT= 9,        ; RET_HBO
                LOOKUP[5]   =1, RESULT=10,        ; DEP_W_O
                LOOKUP[105] =1, RESULT=11,        ; RET_W_O
                LOOKUP[6]   =1, RESULT=12,        ; DEP_O_O
                LOOKUP[106] =1, RESULT=13,        ; RET_O_O
                LOOKUP[7]   =1, RESULT=14,        ; DEP_IX
                LOOKUP[107] =1, RESULT=15,        ; RET_IX
                LOOKUP[8]   =1, RESULT=16,        ; DEP_XI
                LOOKUP[108] =1, RESULT=17         ; RET_XI

            ; Peak Hour to Peak Period Ratio
            @PH_NAME@_DEP_HBW   = PKFAC(1  ,@PEAKHOUR@)/(PKFAC(1  ,@PH_AM@) + PKFAC(1  ,@PH_PM@) + PKFAC(101,@PH_AM@) + PKFAC(101,@PH_PM@))
            @PH_NAME@_RET_HBW   = PKFAC(101,@PEAKHOUR@)/(PKFAC(1  ,@PH_AM@) + PKFAC(1  ,@PH_PM@) + PKFAC(101,@PH_AM@) + PKFAC(101,@PH_PM@))
            @PH_NAME@_DEP_HBS   = PKFAC(2  ,@PEAKHOUR@)/(PKFAC(2  ,@PH_AM@) + PKFAC(2  ,@PH_PM@) + PKFAC(102,@PH_AM@) + PKFAC(102,@PH_PM@))
            @PH_NAME@_RET_HBS   = PKFAC(102,@PEAKHOUR@)/(PKFAC(2  ,@PH_AM@) + PKFAC(2  ,@PH_PM@) + PKFAC(102,@PH_AM@) + PKFAC(102,@PH_PM@))
            @PH_NAME@_DEP_HBSch = PKFAC(3  ,@PEAKHOUR@)/(PKFAC(3  ,@PH_AM@) + PKFAC(3  ,@PH_PM@) + PKFAC(103,@PH_AM@) + PKFAC(103,@PH_PM@))
            @PH_NAME@_RET_HBSch = PKFAC(103,@PEAKHOUR@)/(PKFAC(3  ,@PH_AM@) + PKFAC(3  ,@PH_PM@) + PKFAC(103,@PH_AM@) + PKFAC(103,@PH_PM@))
            @PH_NAME@_DEP_HBO   = PKFAC(4  ,@PEAKHOUR@)/(PKFAC(4  ,@PH_AM@) + PKFAC(4  ,@PH_PM@) + PKFAC(104,@PH_AM@) + PKFAC(104,@PH_PM@))
            @PH_NAME@_RET_HBO   = PKFAC(104,@PEAKHOUR@)/(PKFAC(4  ,@PH_AM@) + PKFAC(4  ,@PH_PM@) + PKFAC(104,@PH_AM@) + PKFAC(104,@PH_PM@))
            @PH_NAME@_DEP_W_O   = PKFAC(5  ,@PEAKHOUR@)/(PKFAC(5  ,@PH_AM@) + PKFAC(5  ,@PH_PM@) + PKFAC(105,@PH_AM@) + PKFAC(105,@PH_PM@))
            @PH_NAME@_RET_W_O   = PKFAC(105,@PEAKHOUR@)/(PKFAC(5  ,@PH_AM@) + PKFAC(5  ,@PH_PM@) + PKFAC(105,@PH_AM@) + PKFAC(105,@PH_PM@))
            @PH_NAME@_DEP_O_O   = PKFAC(6  ,@PEAKHOUR@)/(PKFAC(6  ,@PH_AM@) + PKFAC(6  ,@PH_PM@) + PKFAC(106,@PH_AM@) + PKFAC(106,@PH_PM@))
            @PH_NAME@_RET_O_O   = PKFAC(106,@PEAKHOUR@)/(PKFAC(6  ,@PH_AM@) + PKFAC(6  ,@PH_PM@) + PKFAC(106,@PH_AM@) + PKFAC(106,@PH_PM@))
            @PH_NAME@_DEP_IX    = PKFAC(7  ,@PEAKHOUR@)/(PKFAC(7  ,@PH_AM@) + PKFAC(7  ,@PH_PM@) + PKFAC(107,@PH_AM@) + PKFAC(107,@PH_PM@))
            @PH_NAME@_RET_IX    = PKFAC(107,@PEAKHOUR@)/(PKFAC(7  ,@PH_AM@) + PKFAC(7  ,@PH_PM@) + PKFAC(107,@PH_AM@) + PKFAC(107,@PH_PM@))
            @PH_NAME@_DEP_XI    = PKFAC(8  ,@PEAKHOUR@)/(PKFAC(8  ,@PH_AM@) + PKFAC(8  ,@PH_PM@) + PKFAC(108,@PH_AM@) + PKFAC(108,@PH_PM@))
            @PH_NAME@_RET_XI    = PKFAC(108,@PEAKHOUR@)/(PKFAC(8  ,@PH_AM@) + PKFAC(8  ,@PH_PM@) + PKFAC(108,@PH_AM@) + PKFAC(108,@PH_PM@))

            ; Peak Hour OD Matrices
            MW[1]  = MI.1.HBW      *@PH_NAME@_DEP_HBW   + MI.1.HBW.T      *@PH_NAME@_RET_HBW
            MW[2]  = MI.1.HBS      *@PH_NAME@_DEP_HBS   + MI.1.HBS.T      *@PH_NAME@_RET_HBS
            MW[3]  = MI.1.HBSch    *@PH_NAME@_DEP_HBSch + MI.1.HBSch.T    *@PH_NAME@_RET_HBSch
            MW[4]  = MI.1.HBO      *@PH_NAME@_DEP_HBO   + MI.1.HBO.T      *@PH_NAME@_RET_HBO
            MW[5]  = MI.1.W_O      *@PH_NAME@_DEP_W_O   + MI.1.W_O.T      *@PH_NAME@_RET_W_O
            MW[6]  = MI.1.O_O      *@PH_NAME@_DEP_O_O   + MI.1.O_O.T      *@PH_NAME@_RET_O_O
            MW[7]  = MI.1.HBW_IX   *@PH_NAME@_DEP_IX    + MI.1.HBW_IX.T   *@PH_NAME@_RET_IX
            MW[8]  = MI.1.HBS_IX   *@PH_NAME@_DEP_IX    + MI.1.HBS_IX.T   *@PH_NAME@_RET_IX
            MW[9]  = MI.1.HBSch_IX *@PH_NAME@_DEP_IX    + MI.1.HBSch_IX.T *@PH_NAME@_RET_IX
            MW[10] = MI.1.HBO_IX   *@PH_NAME@_DEP_IX    + MI.1.HBO_IX.T   *@PH_NAME@_RET_IX
            MW[11] = MI.1.W_O_IX   *@PH_NAME@_DEP_IX    + MI.1.W_O_IX.T   *@PH_NAME@_RET_IX
            MW[12] = MI.1.O_O_IX   *@PH_NAME@_DEP_IX    + MI.1.O_O_IX.T   *@PH_NAME@_RET_IX
            MW[13] = MI.1.HBW_XI   *@PH_NAME@_DEP_XI    + MI.1.HBW_XI.T   *@PH_NAME@_RET_XI
            MW[14] = MI.1.HBS_XI   *@PH_NAME@_DEP_XI    + MI.1.HBS_XI.T   *@PH_NAME@_RET_XI
            MW[15] = MI.1.HBSch_XI *@PH_NAME@_DEP_XI    + MI.1.HBSch_XI.T *@PH_NAME@_RET_XI
            MW[16] = MI.1.HBO_XI   *@PH_NAME@_DEP_XI    + MI.1.HBO_XI.T   *@PH_NAME@_RET_XI
            MW[17] = MI.1.W_O_XI   *@PH_NAME@_DEP_XI    + MI.1.W_O_XI.T   *@PH_NAME@_RET_XI
            MW[18] = MI.1.O_O_XI   *@PH_NAME@_DEP_XI    + MI.1.O_O_XI.T   *@PH_NAME@_RET_XI

        ENDRUN
    ENDLOOP              ; Peak Hour Loop End
    
    ; STEP 8b: OP PA to OD
    RUN PGM=MATRIX PRNFILE=".\outputs\step8b.prn" MSG='STEP 8b: OP PA to OD'
        MATI[1] = "outputs\TEMP_PA_@YEAR@_OP.MAT"
        MATO    = "outputs\TEMP_OD_@YEAR@_OP.MAT",
                   MO=1-18,
                   NAME=HBW,HBS,HBSch,HBO,W_O,O_O,HBW_IX,HBS_IX,HBSch_IX,HBO_IX,W_O_IX,O_O_IX,HBW_XI,HBS_XI,HBSch_XI,HBO_XI,W_O_XI,O_O_XI

        LOOKUP,                               ; Hourly Factor Lookup
            FILE="inputs\HourlyFactors.csv",
            NAME=OPFAC,
            LOOKUP[1]   =1, RESULT= 2,        ; DEP_HBW
            LOOKUP[101] =1, RESULT= 3,        ; RET_HBW
            LOOKUP[2]   =1, RESULT= 4,        ; DEP_HBS
            LOOKUP[102] =1, RESULT= 5,        ; RET_HBS
            LOOKUP[3]   =1, RESULT= 6,        ; DEP_HBSch
            LOOKUP[103] =1, RESULT= 7,        ; RET_HBSch
            LOOKUP[4]   =1, RESULT= 8,        ; DEP_HBO
            LOOKUP[104] =1, RESULT= 9,        ; RET_HBO
            LOOKUP[5]   =1, RESULT=10,        ; DEP_W_O
            LOOKUP[105] =1, RESULT=11,        ; RET_W_O
            LOOKUP[6]   =1, RESULT=12,        ; DEP_O_O
            LOOKUP[106] =1, RESULT=13,        ; RET_O_O
            LOOKUP[7]   =1, RESULT=14,        ; DEP_IX
            LOOKUP[107] =1, RESULT=15,        ; RET_IX
            LOOKUP[8]   =1, RESULT=16,        ; DEP_XI
            LOOKUP[108] =1, RESULT=17         ; RET_XI

        ; Depature and Return Factors
        OP_DEP_HBW   = OPFAC(1  ,21)/(OPFAC(1  ,21) + OPFAC(101,21))
        OP_RET_HBW   = OPFAC(101,21)/(OPFAC(1  ,21) + OPFAC(101,21))
        OP_DEP_HBS   = OPFAC(2  ,21)/(OPFAC(2  ,21) + OPFAC(102,21))
        OP_RET_HBS   = OPFAC(102,21)/(OPFAC(2  ,21) + OPFAC(102,21))
        OP_DEP_HBSch = OPFAC(3  ,21)/(OPFAC(3  ,21) + OPFAC(103,21))
        OP_RET_HBSch = OPFAC(103,21)/(OPFAC(3  ,21) + OPFAC(103,21))
        OP_DEP_HBO   = OPFAC(4  ,21)/(OPFAC(4  ,21) + OPFAC(104,21))
        OP_RET_HBO   = OPFAC(104,21)/(OPFAC(4  ,21) + OPFAC(104,21))
        OP_DEP_W_O   = OPFAC(5  ,21)/(OPFAC(5  ,21) + OPFAC(105,21))
        OP_RET_W_O   = OPFAC(105,21)/(OPFAC(5  ,21) + OPFAC(105,21))
        OP_DEP_O_O   = OPFAC(6  ,21)/(OPFAC(6  ,21) + OPFAC(106,21))
        OP_RET_O_O   = OPFAC(106,21)/(OPFAC(6  ,21) + OPFAC(106,21))
        OP_DEP_IX    = OPFAC(7  ,21)/(OPFAC(7  ,21) + OPFAC(107,21))
        OP_RET_IX    = OPFAC(107,21)/(OPFAC(7  ,21) + OPFAC(107,21))
        OP_DEP_XI    = OPFAC(8  ,21)/(OPFAC(8  ,21) + OPFAC(108,21))
        OP_RET_XI    = OPFAC(108,21)/(OPFAC(8  ,21) + OPFAC(108,21))

        ; Off Peak OD
        MW[1]  = MI.1.HBW      *OP_DEP_HBW   + MI.1.HBW.T      *OP_RET_HBW
        MW[2]  = MI.1.HBS      *OP_DEP_HBS   + MI.1.HBS.T      *OP_RET_HBS
        MW[3]  = MI.1.HBSch    *OP_DEP_HBSch + MI.1.HBSch.T    *OP_RET_HBSch
        MW[4]  = MI.1.HBO      *OP_DEP_HBO   + MI.1.HBO.T      *OP_RET_HBO
        MW[5]  = MI.1.W_O      *OP_DEP_W_O   + MI.1.W_O.T      *OP_RET_W_O
        MW[6]  = MI.1.O_O      *OP_DEP_O_O   + MI.1.O_O.T      *OP_RET_O_O
        MW[7]  = MI.1.HBW_IX   *OP_DEP_IX    + MI.1.HBW_IX.T   *OP_RET_IX
        MW[8]  = MI.1.HBS_IX   *OP_DEP_IX    + MI.1.HBS_IX.T   *OP_RET_IX
        MW[9]  = MI.1.HBSch_IX *OP_DEP_IX    + MI.1.HBSch_IX.T *OP_RET_IX
        MW[10] = MI.1.HBO_IX   *OP_DEP_IX    + MI.1.HBO_IX.T   *OP_RET_IX
        MW[11] = MI.1.W_O_IX   *OP_DEP_IX    + MI.1.W_O_IX.T   *OP_RET_IX
        MW[12] = MI.1.O_O_IX   *OP_DEP_IX    + MI.1.O_O_IX.T   *OP_RET_IX
        MW[13] = MI.1.HBW_XI   *OP_DEP_XI    + MI.1.HBW_XI.T   *OP_RET_XI
        MW[14] = MI.1.HBS_XI   *OP_DEP_XI    + MI.1.HBS_XI.T   *OP_RET_XI
        MW[15] = MI.1.HBSch_XI *OP_DEP_XI    + MI.1.HBSch_XI.T *OP_RET_XI
        MW[16] = MI.1.HBO_XI   *OP_DEP_XI    + MI.1.HBO_XI.T   *OP_RET_XI
        MW[17] = MI.1.W_O_XI   *OP_DEP_XI    + MI.1.W_O_XI.T   *OP_RET_XI
        MW[18] = MI.1.O_O_XI   *OP_DEP_XI    + MI.1.O_O_XI.T   *OP_RET_XI
    ENDRUN
    ; ------------------------------------------------------------------------------
    ; STEP 9a: Create through trip matrix from txt format
    ; Re-format txt file to mat file
    RUN PGM=MATRIX PRNFILE=".\outputs\step9a.prn" MSG='STEP 9a: Create through trip matrix from txt format'

        FILEI MATI="inputs\THRU_@YEAR@.TXT", PATTERN=IJM:V, FIELDS=#1,2,0,3  ; Daily Through Trips
        FILEO MATO="outputs\THRU_@YEAR@.MAT",  MO=1                          ; Daily Through Trips, mat format
        PAR ZONES=1723
        MW[1]=MI.1.1
    ENDRUN
    ; ------------------------------------------------------------------------------
    ; STEP 9b: Peak Hour Through Trips
    LOOP hr=1,2          ; Peak Hour Loop Start
        IF (hr=1)
            PEAKHOUR = 7
            PH_NAME  = 'AM1'
        ELSE
            PEAKHOUR = 17
            PH_NAME  = 'PM1'
        ENDIF
        RUN PGM=MATRIX PRNFILE=".\outputs\step9b_@PH_NAME@.prn" MSG='STEP 9b: Peak Hour Through Trips'
            FILEI MATI="outputs\THRU_@YEAR@.MAT"
            FILEO MATO="outputs\THRU_@YEAR@_@PH_NAME@.MAT", MO=1
            LOOKUP,                             ; Hourly Factor Lookup
                FILE="inputs\HourlyFactors.csv",
                NAME=PKFAC,
                LOOKUP[1] =1, RESULT=18,        ; DEP_XX
                LOOKUP[2] =1, RESULT=19         ; RET_XX

            MW[1] = MI.1.1 * PKFAC(1 ,@PEAKHOUR@)/100 + MI.1.1.T * PKFAC(111,@PEAKHOUR@)/100

        ENDRUN
    ENDLOOP              ; Peak Hour Loop End
    ; ------------------------------------------------------------------------------
    ; STEP 9c: Off Peak Through Trips
    RUN PGM=MATRIX PRNFILE=".\outputs\step9c.prn" MSG='STEP 9c: Off Peak Through Trips'
        FILEI MATI[1]="outputs\THRU_@YEAR@.MAT"
              MATI[2]="outputs\THRU_@YEAR@_AM1.MAT"
              MATI[3]="outputs\THRU_@YEAR@_PM1.MAT"
        FILEO MATO   ="outputs\THRU_@YEAR@_OP.MAT", MO=1
            MW[1] = MI.1.1 - MI.2.1 - MI.3.1
    ENDRUN
    ; ------------------------------------------------------------------------------
    ; STEP 10: Calculate Complete OD Matrix
    LOOP p=1,3          ; Loop for Peak Hour Matrices and Off-Peak Matrix
        IF (p=1) PER = 'AM1'
        IF (p=2) PER = 'PM1'
        IF (p=3) PER = 'OP'
        RUN PGM=MATRIX PRNFILE=".\outputs\step10_@PER@.prn" MSG='STEP 10: Calculate Complete OD Matrix'

            MATI[1]="outputs\TEMP_OD_@YEAR@_@PER@.MAT"    ; Internal PA Trips
            MATI[2]="outputs\THRU_@YEAR@_@PER@.MAT"       ; Through Trips
            MATO   ="outputs\OD_@YEAR@_@PER@.MAT",        ; PA/OD Trips
                    MO=1-19,
                    NAME=HBW,HBS,HBSch,HBO,W_O,O_O,HBW_IX,HBS_IX,HBSch_IX,HBO_IX,W_O_IX,O_O_IX,HBW_XI,HBS_XI,HBSch_XI,HBO_XI,W_O_XI,O_O_XI,XX

            FILLMW MW[1]=MI.1.HBW,HBS,HBSch,HBO,W_O,O_O,HBW_IX,HBS_IX,HBSch_IX,HBO_IX,W_O_IX,O_O_IX,HBW_XI,HBS_XI,HBSch_XI,HBO_XI,W_O_XI,O_O_XI
            MW[19]=MI.2.1

            ; Off-Peak IX IX trips PA to OD
            IF (@p@=3)
              LOOKUP,                               ; Hourly Factor Lookup File
                FILE="inputs\HourlyFactors.csv",
                NAME=PKFAC,
                LOOKUP[1]  =1, RESULT=14,        ; DEP_IX
                LOOKUP[2]  =1, RESULT=15,        ; RET_IX
                LOOKUP[3]  =1, RESULT=16,        ; DEP_XI
                LOOKUP[4]  =1, RESULT=17         ; RET_XI

                ; Off Peak Factor
                @PER@_DEP_IX    = 50 - (PKFAC(1  ,7) + PKFAC(1  ,17))
                @PER@_RET_IX    = 50 - (PKFAC(2  ,7) + PKFAC(2  ,17))
                @PER@_DEP_XI    = 50 - (PKFAC(3  ,7) + PKFAC(3  ,17))
                @PER@_RET_XI    = 50 - (PKFAC(4  ,7) + PKFAC(4  ,17))

                @PER@_DEP_IX_PCNT = @PER@_DEP_IX / (@PER@_DEP_IX + @PER@_RET_IX)
                @PER@_RET_IX_PCNT = @PER@_RET_IX / (@PER@_DEP_IX + @PER@_RET_IX)
                @PER@_DEP_XI_PCNT = @PER@_DEP_XI / (@PER@_DEP_XI + @PER@_RET_XI)
                @PER@_RET_XI_PCNT = @PER@_RET_XI / (@PER@_DEP_XI + @PER@_RET_XI)

                ; IX XI trips PA to OD
                MW[7]  = MI.1.HBW_IX   * @PER@_DEP_IX_PCNT + MI.1.HBW_IX.T   * @PER@_RET_IX_PCNT
                MW[8]  = MI.1.HBS_IX   * @PER@_DEP_IX_PCNT + MI.1.HBS_IX.T   * @PER@_RET_IX_PCNT
                MW[9]  = MI.1.HBSch_IX * @PER@_DEP_IX_PCNT + MI.1.HBSch_IX.T * @PER@_RET_IX_PCNT
                MW[10] = MI.1.HBO_IX   * @PER@_DEP_IX_PCNT + MI.1.HBO_IX.T   * @PER@_RET_IX_PCNT
                MW[11] = MI.1.W_O_IX   * @PER@_DEP_IX_PCNT + MI.1.W_O_IX.T   * @PER@_RET_IX_PCNT
                MW[12] = MI.1.O_O_IX   * @PER@_DEP_IX_PCNT + MI.1.O_O_IX.T   * @PER@_RET_IX_PCNT
                MW[13] = MI.1.HBW_XI   * @PER@_DEP_XI_PCNT + MI.1.HBW_XI.T   * @PER@_RET_XI_PCNT
                MW[14] = MI.1.HBS_XI   * @PER@_DEP_XI_PCNT + MI.1.HBS_XI.T   * @PER@_RET_XI_PCNT
                MW[15] = MI.1.HBSch_XI * @PER@_DEP_XI_PCNT + MI.1.HBSch_XI.T * @PER@_RET_XI_PCNT
                MW[16] = MI.1.HBO_XI   * @PER@_DEP_XI_PCNT + MI.1.HBO_XI.T   * @PER@_RET_XI_PCNT
                MW[17] = MI.1.W_O_XI   * @PER@_DEP_XI_PCNT + MI.1.W_O_XI.T   * @PER@_RET_XI_PCNT
                MW[18] = MI.1.O_O_XI   * @PER@_DEP_XI_PCNT + MI.1.O_O_XI.T   * @PER@_RET_XI_PCNT
            ENDIF
        ENDRUN
    ENDLOOP
    ; ------------------------------------------------------------------------------
    ; STEP 11: Assignment
    ; If Cluster
    IF (iteration<3)
        *cluster PeriodAssignment 1,2 start exit
        MAXPID=2
        AssnClusterFiles='PeriodAssignment1.script.END,PeriodAssignment2.script.END'
    ELSEIF (iteration=3)
        *cluster PeriodAssignment 1,2,3 start exit
        MAXPID=3
        AssnClusterFiles='PeriodAssignment1.script.END,PeriodAssignment2.script.END,PeriodAssignment3.script.END'
    ENDIF
    LOOP p=1,3
        IF (p=1) PER = 'AM1'
        IF (p=2) PER = 'OP'
        IF (p=3)
            PER = 'PM1'
            IF (iteration<3) break
        ENDIF

        ; Cluster
        IF (p=1) PID = 1
        IF (p=2) PID = 2
        IF (p=3) PID = 3

        ; SOV loading EXCLUDEGRP
        IF (p=1) SOVLINKEXCLUDEGROUP = '2-4'
        IF (p=2) SOVLINKEXCLUDEGROUP = '2'
        IF (p=3) SOVLINKEXCLUDEGROUP = '2-4'

    ;Cluster
    DistributeMultiStep ProcessID='PeriodAssignment', ProcessNum=@pid@

        capfac = 1.0
        IF (PER = 'OP') capfac = 10  ; Temporary Test: Factor NETI capacity by 10 to get off-peak period capacity

        RUN PGM=MATRIX   PRNFILE=".\outputs\step11a_@PER@.prn"  MSG='STEP 11a: Split trips to SOV and HOV users'
            MATI[1]  = "outputs\OD_@YEAR@_@PER@.MAT"     ; OD Matrix
            MATI[2]  = "inputs\HOVFactors_@YEAR@.tpm"    ; HBW HOV users rates, calculated from Old SPRTA model
            MATO     = "outputs\OD_@YEAR@_@PER@_SOVHOV.MAT",
                        MO=1-19,21-39, NAME=HBWSOV,  HBSSOV,  HBSCSOV,  HBOSOV,  WOSOV,  OOSOV,
                                            HBWIXSOV,HBSIXSOV,HBSCIXSOV,HBOIXSOV,WOIXSOV,OOIXSOV,
                                            HBWXISOV,HBSXISOV,HBSCXISOV,HBOXISOV,WOXISOV,OOXISOV,XXSOV,
                                            HBWHOV,  HBSHOV,  HBSCHOV,  HBOHOV,  WOHOV,  OOHOV,
                                            HBWIXHOV,HBSIXHOV,HBSCIXHOV,HBOIXHOV,WOIXHOV,OOIXHOV,
                                            HBWXIHOV,HBSXIHOV,HBSCXIHOV,HBOXIHOV,WOXIHOV,OOXIHOV,XXHOV
            ; Split the trip matrices to SOV and HOV
            ; HBW
            MW[21] = MI.1.HBW * MI.2.1   ; HOV lane users
            MW[1]  = MI.1.HBW - MW[21]   ; Other trips
            
            ; HBShop, HBSchool, HBO
            MW[22] = MI.1.HBS   * 0.15
            MW[23] = MI.1.HBSch * 0.26
            MW[24] = MI.1.HBO   * 0.21
            MW[2]  = MI.1.HBS   - MW[22]
            MW[3]  = MI.1.HBSch - MW[23]
            MW[4]  = MI.1.HBO   - MW[24]

            ; Work-Other, Other-Other, Thru Trips
            MW[25] = MI.1.W_O * 0.06
            MW[26] = MI.1.O_O * 0.23
            MW[39] = MI.1.XX  * 0.12
            MW[5]  = MI.1.W_O - MW[25]
            MW[6]  = MI.1.O_O - MW[26]
            MW[19] = MI.1.XX  - MW[39]

            ; IX XI trips
            MW[27] = MI.1.HBW_IX    * MI.2.2
            MW[28] = MI.1.HBS_IX    * MI.2.2
            MW[29] = MI.1.HBSch_IX  * MI.2.2
            MW[30] = MI.1.HBO_IX    * MI.2.2
            MW[31] = MI.1.W_O_IX    * MI.2.2
            MW[32] = MI.1.O_O_IX    * MI.2.2
            MW[33] = MI.1.HBW_XI    * MI.2.2
            MW[34] = MI.1.HBS_XI    * MI.2.2
            MW[35] = MI.1.HBSch_XI  * MI.2.2
            MW[36] = MI.1.HBO_XI    * MI.2.2
            MW[37] = MI.1.W_O_XI    * MI.2.2
            MW[38] = MI.1.O_O_XI    * MI.2.2

            MW[7]  = MI.1.HBW_IX    - MW[27]
            MW[8]  = MI.1.HBS_IX    - MW[28]
            MW[9]  = MI.1.HBSch_IX  - MW[29]
            MW[10] = MI.1.HBO_IX    - MW[30]
            MW[11] = MI.1.W_O_IX    - MW[31]
            MW[12] = MI.1.O_O_IX    - MW[32]
            MW[13] = MI.1.HBW_XI    - MW[33]
            MW[14] = MI.1.HBS_XI    - MW[34]
            MW[15] = MI.1.HBSch_XI  - MW[35]
            MW[16] = MI.1.HBO_XI    - MW[36]
            MW[17] = MI.1.W_O_XI    - MW[37]
            MW[18] = MI.1.O_O_XI    - MW[38]
        ENDRUN

        RUN PGM=HIGHWAY  PRNFILE=".\outputs\step11b_@PER@.prn" MSG='STEP 11b: Assignment'

            ; *** FILE I/O ***
            NETI     = "outputs\Roads_@YEARNet@.net"         ; BASE NETWORK
            TURNPENI = "inputs\TURNPEN_@YEARNet@.CSV"        ; TURN PENALITY
            MATI[1]  = "outputs\OD_@YEAR@_@PER@_SOVHOV.MAT"  ; OD Matrix
            NETO     = "outputs\LOADED_@YEAR@_@PER@.NET"     ; LOADED NETWORK

            CAPFAC = @capfac@
            ; *** PARAMETERS ***
            COMBINE=EQUI,MAXITERS=60,GAP=0,aad=0.005,raad=0.00005,rmse=0.001

            ; Capacity of each CAPCLASS - from SACSIM19
              SPDCAP CAPACITY[1] =2000,1000,850,800,700,1500,0,2000,1500    ;basic capacity classes 1-9 | SPDCAP CAPACITY[1]=2000,1000,850,800,700,1500,0,2000,1500
              SPDCAP CAPACITY[11]=0,1500,0,0,0,2000,0,0,0                   ;special classes:  12=hi-cap river crossing;16=hi-cap ramp | SPDCAP CAPACITY[11]=0,1500,0,0,0,2000,0,0,0
              SPDCAP CAPACITY[21]=0,1000,0,750,500,500,0,0,0                ;special classes:  22=rural state hwy; 24=rural min art; 26=lo-cap ramp | SPDCAP CAPACITY[21]=0,1000,0,750,0,500,0,0,0
                                                                            ;added 25=minor collector
              SPDCAP CAPACITY[51]=2000,0,0,0,0,1500,0,0,0                   ;Auxiliary lane classes: 51 = Aux links >1 mile; 56 = Aux links <1 mile | SPDCAP CAPACITY[51]=2000,0,0,0,0,1500,0,0,0
              SPDCAP CAPACITY[62]=0,0                                       ;special classes:  62=pnr dummy link; 63=centroid conn
              SPDCAP CAPACITY[99]=0

            PHASE=LINKREAD
    		        t0 = li.distance * 60 / CmpNumRetNum(li.speed,'=',0,1,li.speed)

                ; preload
                IF (@p@ = 1) PREVVOL = LI.PREVOL_AM
                IF (@p@ = 2) PREVVOL = LI.PREVOL_OP
                IF (@p@ = 3) PREVVOL = LI.PREVOL_PM

                ; Link Class - for congested travel time calculation
                IF (LI.CAPCLASS=1,6,8,9,16,18,26,36,40,46,51,56)  ; Freeway or freeway ramps
                    LINKCLASS=1
                ELSEIF (LI.CAPCLASS=2,22,24)                      ; express and other highways
                    LINKCLASS=2
                ELSE
                    LINKCLASS=3
                ENDIF

                ; Define Group
                IF (LI.HOVLINK=0) ADDTOGROUP=1        ; no restriction
                IF (LI.HOVLINK=1) ADDTOGROUP=2        ; walk
                IF (LI.HOVLINK=2) ADDTOGROUP=3        ; HOV lanes
                IF (LI.HOVLINK=3) ADDTOGROUP=4        ; HOV bypassses
                IF (li.SPEED  <3) ADDTOGROUP=2        ; disabled links
            ENDPHASE

            FUNCTION {
            ;   Conical (2 - beta) - alpha(1-x) +
            ;           sqrt(alpha^2*(1-x)^2 + beta^2)
            ;   where x = factor*v/c,
            ;         beta=(2*alpha-1)/(2*alpha-2)
            ;   From SACSIM19
                ; LINKCLASS = 1
                TC[1] = T0*min((9/10-6.0*(1-0.88*(V/C))+sqrt(36.0*(1-0.88*(V/C))*(1-0.88*(V/C))+121/100)),9.1+0.5*(V/C))
                ; LINKCLASS = 2
                TC[2] = T0*min((7/8-5.0*(1-0.86*(V/C))+sqrt(25.0*(1-0.86*(V/C))*(1-0.86*(V/C))+81/64)),7.2+0.5*(V/C))
                ; LINKCLASS = 3
                TC[3] = T0*min((5/6-4.0*(1-0.83*(V/C))+sqrt(16.0*(1-0.83*(V/C))*(1-0.83*(V/C))+49/36)),5.3+0.5*(V/C))

                ; USE TOTAL VOL FOR CAPACITY RESTRAINT
                V     = PREVVOL + VOL[1]  + VOL[2]  + VOL[3]  + VOL[4]  + VOL[5]  + VOL[6]
                                + VOL[7]  + VOL[8]  + VOL[9]  + VOL[10] + VOL[11] + VOL[12]
                                + VOL[13] + VOL[14] + VOL[15] + VOL[16] + VOL[17] + VOL[18] + VOL[19]
                                + VOL[21] + VOL[22] + VOL[23] + VOL[24] + VOL[25] + VOL[26] 
                                + VOL[27] + VOL[28] + VOL[29] + VOL[30] + VOL[31] + VOL[32]
                                + VOL[33] + VOL[34] + VOL[35] + VOL[36] + VOL[37] + VOL[38] + VOL[39]
                COST  = TIME                      ; TIME AS SYSTEM COST
            }

            ;------ path load
            PHASE=ILOOP
                PATHLOAD PATH = COST, EXCLUDEGRP=@SOVLINKEXCLUDEGROUP@, PENI=1,      ; SOV loading, no HOV lanes
                         VOL[1]  = MI.1.HBWSOV,
                         VOL[2]  = MI.1.HBSSOV,
                         VOL[3]  = MI.1.HBSCSOV,
                         VOL[4]  = MI.1.HBOSOV,
                         VOL[5]  = MI.1.WOSOV,
                         VOL[6]  = MI.1.OOSOV,
                         VOL[7]  = MI.1.HBWIXSOV,
                         VOL[8]  = MI.1.HBSIXSOV,
                         VOL[9]  = MI.1.HBSCIXSOV,
                         VOL[10] = MI.1.HBOIXSOV,
                         VOL[11] = MI.1.WOIXSOV,
                         VOL[12] = MI.1.OOIXSOV,
                         VOL[13] = MI.1.HBWXISOV,
                         VOL[14] = MI.1.HBSXISOV,
                         VOL[15] = MI.1.HBSCXISOV,
                         VOL[16] = MI.1.HBOXISOV,
                         VOL[17] = MI.1.WOXISOV,
                         VOL[18] = MI.1.OOXISOV,
                         VOL[19] = MI.1.XXSOV

                         PATH = COST, EXCLUDEGRP=2, PENI=1,                         ; HOV loading
                         VOL[21] = MI.1.HBWHOV,
                         VOL[22] = MI.1.HBSHOV,
                         VOL[23] = MI.1.HBSCHOV,
                         VOL[24] = MI.1.HBOHOV,
                         VOL[25] = MI.1.WOHOV,
                         VOL[26] = MI.1.OOHOV,
                         VOL[27] = MI.1.HBWIXHOV,
                         VOL[28] = MI.1.HBSIXHOV,
                         VOL[29] = MI.1.HBSCIXHOV,
                         VOL[30] = MI.1.HBOIXHOV,
                         VOL[31] = MI.1.WOIXHOV,
                         VOL[32] = MI.1.OOIXHOV,
                         VOL[33] = MI.1.HBWXIHOV,
                         VOL[34] = MI.1.HBSXIHOV,
                         VOL[35] = MI.1.HBSCXIHOV,
                         VOL[36] = MI.1.HBOXIHOV,
                         VOL[37] = MI.1.WOXIHOV,
                         VOL[38] = MI.1.OOXIHOV,
                         VOL[39] = MI.1.XXHOV
            ENDPHASE
        ENDRUN

    ;Cluster
    EndDistributeMultiStep
        IF (pid=MAXPID)
          Wait4Files Files=@AssnClusterFiles@,
          CheckReturnCode=T,
          PrintFiles=Merge,
          DelDistribFiles=T
        ENDIF

    ENDLOOP
    ; ------------------------------------------------------------------------------
    ; Close Clusters
    *cluster PeriodAssignment 1,2,3 close exit
ENDLOOP
; Model feedback loop end
; ------------------------------------------------------------------------------
; STEP 12: Merge Assigned Networks to Daily Loaded Network
RUN PGM=NETWORK PRNFILE=".\outputs\step12.prn" MSG='STEP 12: Merge Assigned Networks to Daily Loaded Network'

    FILEI LINKI[1]="outputs\LOADED_@YEAR@_AM1.NET"
    FILEI LINKI[2]="outputs\LOADED_@YEAR@_PM1.NET"
    FILEI LINKI[3]="outputs\LOADED_@YEAR@_OP.NET"
    FILEO NETO    ="outputs\LOADED_@YEAR@_DAILY_temp.NET",
                   EXCLUDE = V_1, VC_1, VT_1, TIME_1 ,CSPD_1 ,VDT_1,
                             V1_1,   V2_1,   V3_1,   V4_1,   V5_1,   V6_1,   V7_1,   V8_1,   V9_1,   V10_1,  V11_1,  V12_1,  V13_1,  V14_1,  V15_1,  V16_1,  V17_1,  V18_1,  V19_1,
                             V1T_1,  V2T_1,  V3T_1,  V4T_1,  V5T_1,  V6T_1,  V7T_1,  V8T_1,  V9T_1,  V10T_1, V11T_1, V12T_1, V13T_1, V14T_1, V15T_1, V16T_1, V17T_1, V18T_1, V19T_1,
                             V21_1,  V22_1,  V23_1,  V24_1,  V25_1,  V26_1,  V27_1,  V28_1,  V29_1,  V30_1,  V31_1,  V32_1,  V33_1,  V34_1,  V35_1,  V36_1,  V37_1,  V38_1,  V39_1,
                             V21T_1, V22T_1, V23T_1, V24T_1, V25T_1, V26T_1, V27T_1, V28T_1, V29T_1, V30T_1, V31T_1, V32T_1, V33T_1, V34T_1, V35T_1, V36T_1, V37T_1, V38T_1, V39T_1
;    FILEO LINKO   = "outputs\LOADED_@YEAR@_DAILY.DBF", FORMAT=DBF,
;                   INCLUDE = A, B, VAL_ID, PREVOL_AM, PREVOL_PM, PREVOL_OP, VOL_AM1, VOL_PM1, VOL_OP, VOL_DAY

    PHASE=LINKMERGE
        ; Total Volumes
        VOL_AM1=round(LI.1.V_1)
        VOL_PM1=round(LI.2.V_1)
        VOL_OP =round(LI.3.V_1)
        VOL_DAY=VOL_AM1 + VOL_PM1 + VOL_OP
        
        ; V/C Ratio
        VC_AM1=LI.1.VC_1
        VC_PM1=LI.2.VC_1
        VC_OP =LI.3.VC_1

        ; Congested Speed
        CSPD_AM1=LI.1.CSPD_1
        CSPD_PM1=LI.2.CSPD_1  
        CSPD_OP =LI.3.CSPD_1

        ; Daily Volumes by Purpose
        V_DAY_HBW      =round(LI.1.V1_1  + LI.2.V1_1  + LI.3.V1_1  + LI.1.V21_1 + LI.2.V21_1 + LI.3.V21_1)
        V_DAY_HBS      =round(LI.1.V2_1  + LI.2.V2_1  + LI.3.V2_1  + LI.1.V22_1 + LI.2.V22_1 + LI.3.V22_1)
        V_DAY_HBSch    =round(LI.1.V3_1  + LI.2.V3_1  + LI.3.V3_1  + LI.1.V23_1 + LI.2.V23_1 + LI.3.V23_1)
        V_DAY_HBO      =round(LI.1.V4_1  + LI.2.V4_1  + LI.3.V4_1  + LI.1.V24_1 + LI.2.V24_1 + LI.3.V24_1)
        V_DAY_W_O      =round(LI.1.V5_1  + LI.2.V5_1  + LI.3.V5_1  + LI.1.V25_1 + LI.2.V25_1 + LI.3.V25_1)
        V_DAY_O_O      =round(LI.1.V6_1  + LI.2.V6_1  + LI.3.V6_1  + LI.1.V26_1 + LI.2.V26_1 + LI.3.V26_1)
        V_DAY_HBW_IX   =round(LI.1.V7_1  + LI.2.V7_1  + LI.3.V7_1  + LI.1.V27_1 + LI.2.V27_1 + LI.3.V27_1)
        V_DAY_HBS_IX   =round(LI.1.V8_1  + LI.2.V8_1  + LI.3.V8_1  + LI.1.V28_1 + LI.2.V28_1 + LI.3.V28_1)
        V_DAY_HBSch_IX =round(LI.1.V9_1  + LI.2.V9_1  + LI.3.V9_1  + LI.1.V29_1 + LI.2.V29_1 + LI.3.V29_1)
        V_DAY_HBO_IX   =round(LI.1.V10_1 + LI.2.V10_1 + LI.3.V10_1 + LI.1.V30_1 + LI.2.V30_1 + LI.3.V30_1)
        V_DAY_W_O_IX   =round(LI.1.V11_1 + LI.2.V11_1 + LI.3.V11_1 + LI.1.V31_1 + LI.2.V31_1 + LI.3.V31_1)
        V_DAY_O_O_IX   =round(LI.1.V12_1 + LI.2.V12_1 + LI.3.V12_1 + LI.1.V32_1 + LI.2.V32_1 + LI.3.V32_1)
        V_DAY_HBW_XI   =round(LI.1.V13_1 + LI.2.V13_1 + LI.3.V13_1 + LI.1.V33_1 + LI.2.V33_1 + LI.3.V33_1)
        V_DAY_HBS_XI   =round(LI.1.V14_1 + LI.2.V14_1 + LI.3.V14_1 + LI.1.V34_1 + LI.2.V34_1 + LI.3.V34_1)
        V_DAY_HBSch_XI =round(LI.1.V15_1 + LI.2.V15_1 + LI.3.V15_1 + LI.1.V35_1 + LI.2.V35_1 + LI.3.V35_1)
        V_DAY_HBO_XI   =round(LI.1.V16_1 + LI.2.V16_1 + LI.3.V16_1 + LI.1.V36_1 + LI.2.V36_1 + LI.3.V36_1)
        V_DAY_W_O_XI   =round(LI.1.V17_1 + LI.2.V17_1 + LI.3.V17_1 + LI.1.V37_1 + LI.2.V37_1 + LI.3.V37_1)
        V_DAY_O_O_XI   =round(LI.1.V18_1 + LI.2.V18_1 + LI.3.V18_1 + LI.1.V38_1 + LI.2.V38_1 + LI.3.V38_1)
        V_DAY_XX       =round(LI.1.V19_1 + LI.2.V19_1 + LI.3.V19_1 + LI.1.V39_1 + LI.2.V39_1 + LI.3.V39_1)
    ENDPHASE
ENDRUN
; ------------------------------------------------------------------------------
; STEP 12b: VMT
RUN PGM=NETWORK PRNFILE=".\outputs\step12b.prn" MSG='STEP 12b: VMT'
    FILEI LINKI = "outputs\LOADED_@YEAR@_DAILY_temp.NET"
    FILEO NETO  = "outputs\LOADED_@YEAR@_DAILY.NET"
    FILEO LINKO = "outputs\LOADED_@YEAR@_DAILY.DBF", FORMAT=DBF,
                   INCLUDE = A, B, Distance, AVGTRVLDST, VAL_ID, PREVOL_AM, PREVOL_PM, PREVOL_OP, VOL_AM1, VOL_PM1, VOL_OP, VOL_DAY, VMT_DAY

    PHASE=LINKMERGE
       ; Excluding external gateway links for speed bin
       IF (LI.1.AVGTRVLDST=0)

          ; Calc VMT for each internal link
          _VMT_AM1 = LI.1.VOL_AM1 * distance
          _VMT_PM1 = LI.1.VOL_PM1 * distance
          _VMT_OP  = LI.1.VOL_OP  * distance
          VMT_DAY  = _VMT_AM1 + _VMT_PM1 + _VMT_OP

          ; Accumulate subtotal for internal VMT
          _INT_VMT = _INT_VMT + VMT_DAY

          ; Accumulate by speed bin
          IF (CSPD_AM1 < 5)                 _VMT_AM1_1 = _VMT_AM1_1 + _VMT_AM1
          IF (CSPD_AM1>= 5 && CSPD_AM1<10)  _VMT_AM1_2 = _VMT_AM1_2 + _VMT_AM1
          IF (CSPD_AM1>=10 && CSPD_AM1<15)  _VMT_AM1_3 = _VMT_AM1_3 + _VMT_AM1
          IF (CSPD_AM1>=15 && CSPD_AM1<20)  _VMT_AM1_4 = _VMT_AM1_4 + _VMT_AM1
          IF (CSPD_AM1>=20 && CSPD_AM1<25)  _VMT_AM1_5 = _VMT_AM1_5 + _VMT_AM1
          IF (CSPD_AM1>=25 && CSPD_AM1<30)  _VMT_AM1_6 = _VMT_AM1_6 + _VMT_AM1
          IF (CSPD_AM1>=30 && CSPD_AM1<35)  _VMT_AM1_7 = _VMT_AM1_7 + _VMT_AM1
          IF (CSPD_AM1>=35 && CSPD_AM1<40)  _VMT_AM1_8 = _VMT_AM1_8 + _VMT_AM1
          IF (CSPD_AM1>=40 && CSPD_AM1<45)  _VMT_AM1_9 = _VMT_AM1_9 + _VMT_AM1
          IF (CSPD_AM1>=45 && CSPD_AM1<50)  _VMT_AM1_10= _VMT_AM1_10+ _VMT_AM1
          IF (CSPD_AM1>=50 && CSPD_AM1<55)  _VMT_AM1_11= _VMT_AM1_11+ _VMT_AM1
          IF (CSPD_AM1>=55 && CSPD_AM1<60)  _VMT_AM1_12= _VMT_AM1_12+ _VMT_AM1
          IF (CSPD_AM1>=60 && CSPD_AM1<=65) _VMT_AM1_13= _VMT_AM1_13+ _VMT_AM1

          IF (CSPD_PM1 < 5)                 _VMT_PM1_1 = _VMT_PM1_1 + _VMT_PM1
          IF (CSPD_PM1>= 5 && CSPD_PM1<10)  _VMT_PM1_2 = _VMT_PM1_2 + _VMT_PM1
          IF (CSPD_PM1>=10 && CSPD_PM1<15)  _VMT_PM1_3 = _VMT_PM1_3 + _VMT_PM1
          IF (CSPD_PM1>=15 && CSPD_PM1<20)  _VMT_PM1_4 = _VMT_PM1_4 + _VMT_PM1
          IF (CSPD_PM1>=20 && CSPD_PM1<25)  _VMT_PM1_5 = _VMT_PM1_5 + _VMT_PM1
          IF (CSPD_PM1>=25 && CSPD_PM1<30)  _VMT_PM1_6 = _VMT_PM1_6 + _VMT_PM1
          IF (CSPD_PM1>=30 && CSPD_PM1<35)  _VMT_PM1_7 = _VMT_PM1_7 + _VMT_PM1
          IF (CSPD_PM1>=35 && CSPD_PM1<40)  _VMT_PM1_8 = _VMT_PM1_8 + _VMT_PM1
          IF (CSPD_PM1>=40 && CSPD_PM1<45)  _VMT_PM1_9 = _VMT_PM1_9 + _VMT_PM1
          IF (CSPD_PM1>=45 && CSPD_PM1<50)  _VMT_PM1_10= _VMT_PM1_10+ _VMT_PM1
          IF (CSPD_PM1>=50 && CSPD_PM1<55)  _VMT_PM1_11= _VMT_PM1_11+ _VMT_PM1
          IF (CSPD_PM1>=55 && CSPD_PM1<60)  _VMT_PM1_12= _VMT_PM1_12+ _VMT_PM1
          IF (CSPD_PM1>=60 && CSPD_PM1<=65) _VMT_PM1_13= _VMT_PM1_13+ _VMT_PM1

          IF (CSPD_OP < 5)                  _VMT_OP_1 = _VMT_OP_1 + _VMT_OP
          IF (CSPD_OP>= 5 && CSPD_OP<10)    _VMT_OP_2 = _VMT_OP_2 + _VMT_OP
          IF (CSPD_OP>=10 && CSPD_OP<15)    _VMT_OP_3 = _VMT_OP_3 + _VMT_OP
          IF (CSPD_OP>=15 && CSPD_OP<20)    _VMT_OP_4 = _VMT_OP_4 + _VMT_OP
          IF (CSPD_OP>=20 && CSPD_OP<25)    _VMT_OP_5 = _VMT_OP_5 + _VMT_OP
          IF (CSPD_OP>=25 && CSPD_OP<30)    _VMT_OP_6 = _VMT_OP_6 + _VMT_OP
          IF (CSPD_OP>=30 && CSPD_OP<35)    _VMT_OP_7 = _VMT_OP_7 + _VMT_OP
          IF (CSPD_OP>=35 && CSPD_OP<40)    _VMT_OP_8 = _VMT_OP_8 + _VMT_OP
          IF (CSPD_OP>=40 && CSPD_OP<45)    _VMT_OP_9 = _VMT_OP_9 + _VMT_OP
          IF (CSPD_OP>=45 && CSPD_OP<50)    _VMT_OP_10= _VMT_OP_10+ _VMT_OP
          IF (CSPD_OP>=50 && CSPD_OP<55)    _VMT_OP_11= _VMT_OP_11+ _VMT_OP
          IF (CSPD_OP>=55 && CSPD_OP<60)    _VMT_OP_12= _VMT_OP_12+ _VMT_OP
          IF (CSPD_OP>=60 && CSPD_OP<=65)   _VMT_OP_13= _VMT_OP_13+ _VMT_OP

          ; Accumulate daily VMT by speed bin (rounded)
          _VMT_DAY_1  = round(_VMT_AM1_1  + _VMT_PM1_1  + _VMT_OP_1)
          _VMT_DAY_2  = round(_VMT_AM1_2  + _VMT_PM1_2  + _VMT_OP_2) 
          _VMT_DAY_3  = round(_VMT_AM1_3  + _VMT_PM1_3  + _VMT_OP_3) 
          _VMT_DAY_4  = round(_VMT_AM1_4  + _VMT_PM1_4  + _VMT_OP_4) 
          _VMT_DAY_5  = round(_VMT_AM1_5  + _VMT_PM1_5  + _VMT_OP_5) 
          _VMT_DAY_6  = round(_VMT_AM1_6  + _VMT_PM1_6  + _VMT_OP_6) 
          _VMT_DAY_7  = round(_VMT_AM1_7  + _VMT_PM1_7  + _VMT_OP_7) 
          _VMT_DAY_8  = round(_VMT_AM1_8  + _VMT_PM1_8  + _VMT_OP_8) 
          _VMT_DAY_9  = round(_VMT_AM1_9  + _VMT_PM1_9  + _VMT_OP_9) 
          _VMT_DAY_10 = round(_VMT_AM1_10 + _VMT_PM1_10 + _VMT_OP_10)
          _VMT_DAY_11 = round(_VMT_AM1_11 + _VMT_PM1_11 + _VMT_OP_11)
          _VMT_DAY_12 = round(_VMT_AM1_12 + _VMT_PM1_12 + _VMT_OP_12)
          _VMT_DAY_13 = round(_VMT_AM1_13 + _VMT_PM1_13 + _VMT_OP_13)

       ; External gateway links for total VMT
       ELSEIF (LI.1.AVGTRVLDST>0)

          ; Calc VMT for each gateway link
          _VMT_AM1 = LI.1.VOL_AM1 * LI.1.AVGTRVLDST
          _VMT_PM1 = LI.1.VOL_PM1 * LI.1.AVGTRVLDST
          _VMT_OP  = LI.1.VOL_OP  * LI.1.AVGTRVLDST
          VMT_DAY  = _VMT_AM1 + _VMT_PM1 + _VMT_OP

          ; Accumulate subtotal of gateway VMT
          _EXT_VMT = _EXT_VMT + VMT_DAY
       ENDIF
          ; Sum of interal and external subtotals (rounded)
          _TOT_VMT = round(_INT_VMT + _EXT_VMT)
    ENDPHASE

    PHASE = SUMMARY
        PRINT,
          FORM= 10.0C,
          LIST= '\n',
          LIST= '   VMT by Congested Speed', '\n',
          LIST= '       (vehicle-miles)', '\n',
          LIST= '-----------------------------', '\n',
          LIST= '  Speed          Daily VMT ',   '\n',
          LIST= ' 0 to  4.9 :    ',  _VMT_DAY_1, '\n',
          LIST= ' 5 to  9.9 :    ',  _VMT_DAY_2, '\n',
          LIST= '10 to 14.9 :    ',  _VMT_DAY_3, '\n',
          LIST= '15 to 19.9 :    ',  _VMT_DAY_4, '\n',
          LIST= '20 to 24.9 :    ',  _VMT_DAY_5, '\n',
          LIST= '25 to 29.9 :    ',  _VMT_DAY_6, '\n',
          LIST= '30 to 34.9 :    ',  _VMT_DAY_7, '\n',
          LIST= '35 to 39.9 :    ',  _VMT_DAY_8, '\n',
          LIST= '40 to 44.9 :    ',  _VMT_DAY_9, '\n',
          LIST= '45 to 49.9 :    ',  _VMT_DAY_10,'\n',
          LIST= '50 to 54.9 :    ',  _VMT_DAY_11,'\n',
          LIST= '55 to 59.9 :    ',  _VMT_DAY_12,'\n',
          LIST= '60 to 65   :    ',  _VMT_DAY_13,'\n',
          LIST= '-----------------------------', '\n',
          LIST= '  Subtotal :    ',  _INT_VMT, '\n\n',
          LIST= '-----------------------------', '\n',
          LIST= '  External :    ',  _EXT_VMT, '\n',
          LIST= ' Total VMT :    ',  _TOT_VMT,
        FILE=.\outputs\VMT_Summary.txt, print=y
    ENDPHASE
ENDRUN
; ------------------------------------------------------------------------------
; STEP 13: Distance Skimming Matrix, path only includes GP facilities
RUN PGM=HWYLOAD PRNFILE=".\outputs\step13.prn" MSG='STEP 13: Distance Skimming Matrix, path only includes GP facilities'
    NETI     = "outputs\Roads_@YEARNet@.net"          ; Model Year Network
    TURNPENI = "inputs\TURNPEN_@YEARNet@.CSV"         ; Turn Penalty
    MATO     = "outputs\SKIM_@YEAR@_Distance.MAT",    ; Distance Skim Matrix
               MO=1, NAME=Distance

    ; PARAMETERS
    ZONES=1723                                

    PHASE=LINKREAD
        SPEED = LI.Speed                      ; Use Free Flow Speed
        IF (LI.HOVLINK=0) ADDTOGROUP=1        ; no restriction
        IF (LI.HOVLINK=1) ADDTOGROUP=2        ; walk
        IF (LI.HOVLINK=2) ADDTOGROUP=3        ; HOV lanes
        IF (LI.HOVLINK=3) ADDTOGROUP=4        ; HOV bypassses
        IF (li.SPEED  <3) ADDTOGROUP=2        ; disabled links
    ENDPHASE

    PHASE=ILOOP
    ; Skim without HOV links
        PATHLOAD PATH=LI.DISTANCE, EXCLUDEGRP=2-4, PENI=1, MW[1]=PATHCOST,       ; Skim distance without HOV links
                           NOACCESS=0                                            ; No Access Cell Value = 0
    ; Intrazonals
        IZ1=LOWEST(1,1,0.005,10000)*0.5
        JLOOP J=I
            MW[1]=IZ1
        ENDJLOOP
    ENDPHASE

ENDRUN
; ------------------------------------------------------------------------------
